(()=>{"use strict";var Ot={31821(W,Q,B){B.d(Q,{n:()=>K});var be=B(45585),G=B(39373);let H=!1;function K(ne){if(H)return;H=!0;const ue=new be.AU(ce=>{self.postMessage(ce)},ce=>new G.Wg(ce,ne));self.onmessage=ce=>{ue.onmessage(ce.data)}}self.onmessage=ne=>{H||K(null)}},81162(W,Q,B){var be=B(31821);/*!-----------------------------------------------------------------------------
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Version: 0.34.1(547870b6881302c5b4ff32173c16d06009e3588f)
 * Released under the MIT license
 * https://github.com/microsoft/monaco-editor/blob/main/LICENSE.txt
 *-----------------------------------------------------------------------------*/function G(e,r){r===void 0&&(r=!1);var i=e.length,t=0,n="",a=0,s=16,o=0,f=0,l=0,u=0,c=0;function h(m,O){for(var E=0,P=0;E<m||!O;){var w=e.charCodeAt(t);if(w>=48&&w<=57)P=P*16+w-48;else if(w>=65&&w<=70)P=P*16+w-65+10;else if(w>=97&&w<=102)P=P*16+w-97+10;else break;t++,E++}return E<m&&(P=-1),P}function p(m){t=m,n="",a=0,s=16,c=0}function d(){var m=t;if(e.charCodeAt(t)===48)t++;else for(t++;t<e.length&&ne(e.charCodeAt(t));)t++;if(t<e.length&&e.charCodeAt(t)===46)if(t++,t<e.length&&ne(e.charCodeAt(t)))for(t++;t<e.length&&ne(e.charCodeAt(t));)t++;else return c=3,e.substring(m,t);var O=t;if(t<e.length&&(e.charCodeAt(t)===69||e.charCodeAt(t)===101))if(t++,(t<e.length&&e.charCodeAt(t)===43||e.charCodeAt(t)===45)&&t++,t<e.length&&ne(e.charCodeAt(t))){for(t++;t<e.length&&ne(e.charCodeAt(t));)t++;O=t}else c=3;return e.substring(m,O)}function v(){for(var m="",O=t;;){if(t>=i){m+=e.substring(O,t),c=2;break}var E=e.charCodeAt(t);if(E===34){m+=e.substring(O,t),t++;break}if(E===92){if(m+=e.substring(O,t),t++,t>=i){c=2;break}var P=e.charCodeAt(t++);switch(P){case 34:m+='"';break;case 92:m+="\\";break;case 47:m+="/";break;case 98:m+="\b";break;case 102:m+="\f";break;case 110:m+=`
`;break;case 114:m+="\r";break;case 116:m+="	";break;case 117:var w=h(4,!0);w>=0?m+=String.fromCharCode(w):c=4;break;default:c=5}O=t;continue}if(E>=0&&E<=31)if(K(E)){m+=e.substring(O,t),c=2;break}else c=6;t++}return m}function g(){if(n="",c=0,a=t,f=o,u=l,t>=i)return a=i,s=17;var m=e.charCodeAt(t);if(H(m)){do t++,n+=String.fromCharCode(m),m=e.charCodeAt(t);while(H(m));return s=15}if(K(m))return t++,n+=String.fromCharCode(m),m===13&&e.charCodeAt(t)===10&&(t++,n+=`
`),o++,l=t,s=14;switch(m){case 123:return t++,s=1;case 125:return t++,s=2;case 91:return t++,s=3;case 93:return t++,s=4;case 58:return t++,s=6;case 44:return t++,s=5;case 34:return t++,n=v(),s=10;case 47:var O=t-1;if(e.charCodeAt(t+1)===47){for(t+=2;t<i&&!K(e.charCodeAt(t));)t++;return n=e.substring(O,t),s=12}if(e.charCodeAt(t+1)===42){t+=2;for(var E=i-1,P=!1;t<E;){var w=e.charCodeAt(t);if(w===42&&e.charCodeAt(t+1)===47){t+=2,P=!0;break}t++,K(w)&&(w===13&&e.charCodeAt(t)===10&&t++,o++,l=t)}return P||(t++,c=1),n=e.substring(O,t),s=13}return n+=String.fromCharCode(m),t++,s=16;case 45:if(n+=String.fromCharCode(m),t++,t===i||!ne(e.charCodeAt(t)))return s=16;case 48:case 49:case 50:case 51:case 52:case 53:case 54:case 55:case 56:case 57:return n+=d(),s=11;default:for(;t<i&&A(m);)t++,m=e.charCodeAt(t);if(a!==t){switch(n=e.substring(a,t),n){case"true":return s=8;case"false":return s=9;case"null":return s=7}return s=16}return n+=String.fromCharCode(m),t++,s=16}}function A(m){if(H(m)||K(m))return!1;switch(m){case 125:case 93:case 123:case 91:case 34:case 58:case 44:case 47:return!1}return!0}function y(){var m;do m=g();while(m>=12&&m<=15);return m}return{setPosition:p,getPosition:function(){return t},scan:r?y:g,getToken:function(){return s},getTokenValue:function(){return n},getTokenOffset:function(){return a},getTokenLength:function(){return t-a},getTokenStartLine:function(){return f},getTokenStartCharacter:function(){return a-u},getTokenError:function(){return c}}}function H(e){return e===32||e===9||e===11||e===12||e===160||e===5760||e>=8192&&e<=8203||e===8239||e===8287||e===12288||e===65279}function K(e){return e===10||e===13||e===8232||e===8233}function ne(e){return e>=48&&e<=57}function ue(e,r,i){var t,n,a,s,o;if(r){for(s=r.offset,o=s+r.length,a=s;a>0&&!jt(e,a-1);)a--;for(var f=o;f<e.length&&!jt(e,f);)f++;n=e.substring(a,f),t=Cr(n,i)}else n=e,t=0,a=0,s=0,o=e.length;var l=jr(i,e),u=!1,c=0,h;i.insertSpaces?h=ce(" ",i.tabSize||4):h="	";var p=G(n,!1),d=!1;function v(){return l+ce(h,t+c)}function g(){var N=p.scan();for(u=!1;N===15||N===14;)u=u||N===14,N=p.scan();return d=N===16||p.getTokenError()!==0,N}var A=[];function y(N,V,D){!d&&(!r||V<o&&D>s)&&e.substring(V,D)!==N&&A.push({offset:V,length:D-V,content:N})}var m=g();if(m!==17){var O=p.getTokenOffset()+a,E=ce(h,t);y(E,a,O)}for(;m!==17;){for(var P=p.getTokenOffset()+p.getTokenLength()+a,w=g(),j="",x=!1;!u&&(w===12||w===13);){var C=p.getTokenOffset()+a;y(" ",P,C),P=p.getTokenOffset()+p.getTokenLength()+a,x=w===12,j=x?v():"",w=g()}if(w===2)m!==1&&(c--,j=v());else if(w===4)m!==3&&(c--,j=v());else{switch(m){case 3:case 1:c++,j=v();break;case 5:case 12:j=v();break;case 13:u?j=v():x||(j=" ");break;case 6:x||(j=" ");break;case 10:if(w===6){x||(j="");break}case 7:case 8:case 9:case 11:case 2:case 4:w===12||w===13?x||(j=" "):w!==5&&w!==17&&(d=!0);break;case 16:d=!0;break}u&&(w===12||w===13)&&(j=v())}w===17&&(j=i.insertFinalNewline?l:"");var F=p.getTokenOffset()+a;y(j,P,F),m=w}return A}function ce(e,r){for(var i="",t=0;t<r;t++)i+=e;return i}function Cr(e,r){for(var i=0,t=0,n=r.tabSize||4;i<e.length;){var a=e.charAt(i);if(a===" ")t++;else if(a==="	")t+=n;else break;i++}return Math.floor(t/n)}function jr(e,r){for(var i=0;i<r.length;i++){var t=r.charAt(i);if(t==="\r")return i+1<r.length&&r.charAt(i+1)===`
`?`\r
`:"\r";if(t===`
`)return`
`}return e&&e.eol||`
`}function jt(e,r){return`\r
`.indexOf(e.charAt(r))!==-1}var Je;(function(e){e.DEFAULT={allowTrailingComma:!1}})(Je||(Je={}));function it(e,r,i){r===void 0&&(r=[]),i===void 0&&(i=Je.DEFAULT);var t=null,n=[],a=[];function s(f){Array.isArray(n)?n.push(f):t!==null&&(n[t]=f)}var o={onObjectBegin:function(){var f={};s(f),a.push(n),n=f,t=null},onObjectProperty:function(f){t=f},onObjectEnd:function(){n=a.pop()},onArrayBegin:function(){var f=[];s(f),a.push(n),n=f,t=null},onArrayEnd:function(){n=a.pop()},onLiteralValue:s,onError:function(f,l,u){r.push({error:f,offset:l,length:u})}};return Er(e,o,i),n[0]}function It(e){if(!e.parent||!e.parent.children)return[];var r=It(e.parent);if(e.parent.type==="property"){var i=e.parent.children[0].value;r.push(i)}else if(e.parent.type==="array"){var t=e.parent.children.indexOf(e);t!==-1&&r.push(t)}return r}function at(e){switch(e.type){case"array":return e.children.map(at);case"object":for(var r=Object.create(null),i=0,t=e.children;i<t.length;i++){var n=t[i],a=n.children[1];a&&(r[n.children[0].value]=at(a))}return r;case"null":case"string":case"number":case"boolean":return e.value;default:return}}function Ir(e,r,i){return i===void 0&&(i=!1),r>=e.offset&&r<e.offset+e.length||i&&r===e.offset+e.length}function Et(e,r,i){if(i===void 0&&(i=!1),Ir(e,r,i)){var t=e.children;if(Array.isArray(t))for(var n=0;n<t.length&&t[n].offset<=r;n++){var a=Et(t[n],r,i);if(a)return a}return e}}function Er(e,r,i){i===void 0&&(i=Je.DEFAULT);var t=G(e,!1);function n(x){return x?function(){return x(t.getTokenOffset(),t.getTokenLength(),t.getTokenStartLine(),t.getTokenStartCharacter())}:function(){return!0}}function a(x){return x?function(C){return x(C,t.getTokenOffset(),t.getTokenLength(),t.getTokenStartLine(),t.getTokenStartCharacter())}:function(){return!0}}var s=n(r.onObjectBegin),o=a(r.onObjectProperty),f=n(r.onObjectEnd),l=n(r.onArrayBegin),u=n(r.onArrayEnd),c=a(r.onLiteralValue),h=a(r.onSeparator),p=n(r.onComment),d=a(r.onError),v=i&&i.disallowComments,g=i&&i.allowTrailingComma;function A(){for(;;){var x=t.scan();switch(t.getTokenError()){case 4:y(14);break;case 5:y(15);break;case 3:y(13);break;case 1:v||y(11);break;case 2:y(12);break;case 6:y(16);break}switch(x){case 12:case 13:v?y(10):p();break;case 16:y(1);break;case 15:case 14:break;default:return x}}}function y(x,C,F){if(C===void 0&&(C=[]),F===void 0&&(F=[]),d(x),C.length+F.length>0)for(var N=t.getToken();N!==17;){if(C.indexOf(N)!==-1){A();break}else if(F.indexOf(N)!==-1)break;N=A()}}function m(x){var C=t.getTokenValue();return x?c(C):o(C),A(),!0}function O(){switch(t.getToken()){case 11:var x=t.getTokenValue(),C=Number(x);isNaN(C)&&(y(2),C=0),c(C);break;case 7:c(null);break;case 8:c(!0);break;case 9:c(!1);break;default:return!1}return A(),!0}function E(){return t.getToken()!==10?(y(3,[],[2,5]),!1):(m(!1),t.getToken()===6?(h(":"),A(),j()||y(4,[],[2,5])):y(5,[],[2,5]),!0)}function P(){s(),A();for(var x=!1;t.getToken()!==2&&t.getToken()!==17;){if(t.getToken()===5){if(x||y(4,[],[]),h(","),A(),t.getToken()===2&&g)break}else x&&y(6,[],[]);E()||y(4,[],[2,5]),x=!0}return f(),t.getToken()!==2?y(7,[2],[]):A(),!0}function w(){l(),A();for(var x=!1;t.getToken()!==4&&t.getToken()!==17;){if(t.getToken()===5){if(x||y(4,[],[]),h(","),A(),t.getToken()===4&&g)break}else x&&y(6,[],[]);j()||y(4,[],[4,5]),x=!0}return u(),t.getToken()!==4?y(8,[4],[]):A(),!0}function j(){switch(t.getToken()){case 3:return w();case 1:return P();case 10:return m(!0);default:return O()}}return A(),t.getToken()===17?i.allowEmptyContent?!0:(y(4,[],[]),!1):j()?(t.getToken()!==17&&y(9,[],[]),!0):(y(4,[],[]),!1)}var Ie=G,Pr=it,Nr=Et,Mr=It,Fr=at;function Vr(e,r,i){return ue(e,r,i)}function Fe(e,r){if(e===r)return!0;if(e==null||r===null||r===void 0||typeof e!=typeof r||typeof e!="object"||Array.isArray(e)!==Array.isArray(r))return!1;var i,t;if(Array.isArray(e)){if(e.length!==r.length)return!1;for(i=0;i<e.length;i++)if(!Fe(e[i],r[i]))return!1}else{var n=[];for(t in e)n.push(t);n.sort();var a=[];for(t in r)a.push(t);if(a.sort(),!Fe(n,a))return!1;for(i=0;i<n.length;i++)if(!Fe(e[n[i]],r[n[i]]))return!1}return!0}function se(e){return typeof e=="number"}function Ae(e){return typeof e<"u"}function pe(e){return typeof e=="boolean"}function Lr(e){return typeof e=="string"}function $r(e,r){if(e.length<r.length)return!1;for(var i=0;i<r.length;i++)if(e[i]!==r[i])return!1;return!0}function Ve(e,r){var i=e.length-r.length;return i>0?e.lastIndexOf(r)===i:i===0?e===r:!1}function ze(e){var r="";$r(e,"(?i)")&&(e=e.substring(4),r="i");try{return new RegExp(e,r+"u")}catch{try{return new RegExp(e,r)}catch{return}}}var Pt;(function(e){e.MIN_VALUE=-2147483648,e.MAX_VALUE=2147483647})(Pt||(Pt={}));var Be;(function(e){e.MIN_VALUE=0,e.MAX_VALUE=2147483647})(Be||(Be={}));var he;(function(e){function r(t,n){return t===Number.MAX_VALUE&&(t=Be.MAX_VALUE),n===Number.MAX_VALUE&&(n=Be.MAX_VALUE),{line:t,character:n}}e.create=r;function i(t){var n=t;return b.objectLiteral(n)&&b.uinteger(n.line)&&b.uinteger(n.character)}e.is=i})(he||(he={}));var J;(function(e){function r(t,n,a,s){if(b.uinteger(t)&&b.uinteger(n)&&b.uinteger(a)&&b.uinteger(s))return{start:he.create(t,n),end:he.create(a,s)};if(he.is(t)&&he.is(n))return{start:t,end:n};throw new Error("Range#create called with invalid arguments["+t+", "+n+", "+a+", "+s+"]")}e.create=r;function i(t){var n=t;return b.objectLiteral(n)&&he.is(n.start)&&he.is(n.end)}e.is=i})(J||(J={}));var Le;(function(e){function r(t,n){return{uri:t,range:n}}e.create=r;function i(t){var n=t;return b.defined(n)&&J.is(n.range)&&(b.string(n.uri)||b.undefined(n.uri))}e.is=i})(Le||(Le={}));var Nt;(function(e){function r(t,n,a,s){return{targetUri:t,targetRange:n,targetSelectionRange:a,originSelectionRange:s}}e.create=r;function i(t){var n=t;return b.defined(n)&&J.is(n.targetRange)&&b.string(n.targetUri)&&(J.is(n.targetSelectionRange)||b.undefined(n.targetSelectionRange))&&(J.is(n.originSelectionRange)||b.undefined(n.originSelectionRange))}e.is=i})(Nt||(Nt={}));var ot;(function(e){function r(t,n,a,s){return{red:t,green:n,blue:a,alpha:s}}e.create=r;function i(t){var n=t;return b.numberRange(n.red,0,1)&&b.numberRange(n.green,0,1)&&b.numberRange(n.blue,0,1)&&b.numberRange(n.alpha,0,1)}e.is=i})(ot||(ot={}));var Mt;(function(e){function r(t,n){return{range:t,color:n}}e.create=r;function i(t){var n=t;return J.is(n.range)&&ot.is(n.color)}e.is=i})(Mt||(Mt={}));var Ft;(function(e){function r(t,n,a){return{label:t,textEdit:n,additionalTextEdits:a}}e.create=r;function i(t){var n=t;return b.string(n.label)&&(b.undefined(n.textEdit)||ge.is(n))&&(b.undefined(n.additionalTextEdits)||b.typedArray(n.additionalTextEdits,ge.is))}e.is=i})(Ft||(Ft={}));var $e;(function(e){e.Comment="comment",e.Imports="imports",e.Region="region"})($e||($e={}));var Vt;(function(e){function r(t,n,a,s,o){var f={startLine:t,endLine:n};return b.defined(a)&&(f.startCharacter=a),b.defined(s)&&(f.endCharacter=s),b.defined(o)&&(f.kind=o),f}e.create=r;function i(t){var n=t;return b.uinteger(n.startLine)&&b.uinteger(n.startLine)&&(b.undefined(n.startCharacter)||b.uinteger(n.startCharacter))&&(b.undefined(n.endCharacter)||b.uinteger(n.endCharacter))&&(b.undefined(n.kind)||b.string(n.kind))}e.is=i})(Vt||(Vt={}));var st;(function(e){function r(t,n){return{location:t,message:n}}e.create=r;function i(t){var n=t;return b.defined(n)&&Le.is(n.location)&&b.string(n.message)}e.is=i})(st||(st={}));var fe;(function(e){e.Error=1,e.Warning=2,e.Information=3,e.Hint=4})(fe||(fe={}));var Lt;(function(e){e.Unnecessary=1,e.Deprecated=2})(Lt||(Lt={}));var $t;(function(e){function r(i){var t=i;return t!=null&&b.string(t.href)}e.is=r})($t||($t={}));var Se;(function(e){function r(t,n,a,s,o,f){var l={range:t,message:n};return b.defined(a)&&(l.severity=a),b.defined(s)&&(l.code=s),b.defined(o)&&(l.source=o),b.defined(f)&&(l.relatedInformation=f),l}e.create=r;function i(t){var n,a=t;return b.defined(a)&&J.is(a.range)&&b.string(a.message)&&(b.number(a.severity)||b.undefined(a.severity))&&(b.integer(a.code)||b.string(a.code)||b.undefined(a.code))&&(b.undefined(a.codeDescription)||b.string((n=a.codeDescription)===null||n===void 0?void 0:n.href))&&(b.string(a.source)||b.undefined(a.source))&&(b.undefined(a.relatedInformation)||b.typedArray(a.relatedInformation,st.is))}e.is=i})(Se||(Se={}));var _e;(function(e){function r(t,n){for(var a=[],s=2;s<arguments.length;s++)a[s-2]=arguments[s];var o={title:t,command:n};return b.defined(a)&&a.length>0&&(o.arguments=a),o}e.create=r;function i(t){var n=t;return b.defined(n)&&b.string(n.title)&&b.string(n.command)}e.is=i})(_e||(_e={}));var ge;(function(e){function r(a,s){return{range:a,newText:s}}e.replace=r;function i(a,s){return{range:{start:a,end:a},newText:s}}e.insert=i;function t(a){return{range:a,newText:""}}e.del=t;function n(a){var s=a;return b.objectLiteral(s)&&b.string(s.newText)&&J.is(s.range)}e.is=n})(ge||(ge={}));var Ee;(function(e){function r(t,n,a){var s={label:t};return n!==void 0&&(s.needsConfirmation=n),a!==void 0&&(s.description=a),s}e.create=r;function i(t){var n=t;return n!==void 0&&b.objectLiteral(n)&&b.string(n.label)&&(b.boolean(n.needsConfirmation)||n.needsConfirmation===void 0)&&(b.string(n.description)||n.description===void 0)}e.is=i})(Ee||(Ee={}));var ee;(function(e){function r(i){var t=i;return typeof t=="string"}e.is=r})(ee||(ee={}));var xe;(function(e){function r(a,s,o){return{range:a,newText:s,annotationId:o}}e.replace=r;function i(a,s,o){return{range:{start:a,end:a},newText:s,annotationId:o}}e.insert=i;function t(a,s){return{range:a,newText:"",annotationId:s}}e.del=t;function n(a){var s=a;return ge.is(s)&&(Ee.is(s.annotationId)||ee.is(s.annotationId))}e.is=n})(xe||(xe={}));var He;(function(e){function r(t,n){return{textDocument:t,edits:n}}e.create=r;function i(t){var n=t;return b.defined(n)&&Xe.is(n.textDocument)&&Array.isArray(n.edits)}e.is=i})(He||(He={}));var De;(function(e){function r(t,n,a){var s={kind:"create",uri:t};return n!==void 0&&(n.overwrite!==void 0||n.ignoreIfExists!==void 0)&&(s.options=n),a!==void 0&&(s.annotationId=a),s}e.create=r;function i(t){var n=t;return n&&n.kind==="create"&&b.string(n.uri)&&(n.options===void 0||(n.options.overwrite===void 0||b.boolean(n.options.overwrite))&&(n.options.ignoreIfExists===void 0||b.boolean(n.options.ignoreIfExists)))&&(n.annotationId===void 0||ee.is(n.annotationId))}e.is=i})(De||(De={}));var We;(function(e){function r(t,n,a,s){var o={kind:"rename",oldUri:t,newUri:n};return a!==void 0&&(a.overwrite!==void 0||a.ignoreIfExists!==void 0)&&(o.options=a),s!==void 0&&(o.annotationId=s),o}e.create=r;function i(t){var n=t;return n&&n.kind==="rename"&&b.string(n.oldUri)&&b.string(n.newUri)&&(n.options===void 0||(n.options.overwrite===void 0||b.boolean(n.options.overwrite))&&(n.options.ignoreIfExists===void 0||b.boolean(n.options.ignoreIfExists)))&&(n.annotationId===void 0||ee.is(n.annotationId))}e.is=i})(We||(We={}));var Ue;(function(e){function r(t,n,a){var s={kind:"delete",uri:t};return n!==void 0&&(n.recursive!==void 0||n.ignoreIfNotExists!==void 0)&&(s.options=n),a!==void 0&&(s.annotationId=a),s}e.create=r;function i(t){var n=t;return n&&n.kind==="delete"&&b.string(n.uri)&&(n.options===void 0||(n.options.recursive===void 0||b.boolean(n.options.recursive))&&(n.options.ignoreIfNotExists===void 0||b.boolean(n.options.ignoreIfNotExists)))&&(n.annotationId===void 0||ee.is(n.annotationId))}e.is=i})(Ue||(Ue={}));var ft;(function(e){function r(i){var t=i;return t&&(t.changes!==void 0||t.documentChanges!==void 0)&&(t.documentChanges===void 0||t.documentChanges.every(function(n){return b.string(n.kind)?De.is(n)||We.is(n)||Ue.is(n):He.is(n)}))}e.is=r})(ft||(ft={}));var Ge=function(){function e(r,i){this.edits=r,this.changeAnnotations=i}return e.prototype.insert=function(r,i,t){var n,a;if(t===void 0?n=ge.insert(r,i):ee.is(t)?(a=t,n=xe.insert(r,i,t)):(this.assertChangeAnnotations(this.changeAnnotations),a=this.changeAnnotations.manage(t),n=xe.insert(r,i,a)),this.edits.push(n),a!==void 0)return a},e.prototype.replace=function(r,i,t){var n,a;if(t===void 0?n=ge.replace(r,i):ee.is(t)?(a=t,n=xe.replace(r,i,t)):(this.assertChangeAnnotations(this.changeAnnotations),a=this.changeAnnotations.manage(t),n=xe.replace(r,i,a)),this.edits.push(n),a!==void 0)return a},e.prototype.delete=function(r,i){var t,n;if(i===void 0?t=ge.del(r):ee.is(i)?(n=i,t=xe.del(r,i)):(this.assertChangeAnnotations(this.changeAnnotations),n=this.changeAnnotations.manage(i),t=xe.del(r,n)),this.edits.push(t),n!==void 0)return n},e.prototype.add=function(r){this.edits.push(r)},e.prototype.all=function(){return this.edits},e.prototype.clear=function(){this.edits.splice(0,this.edits.length)},e.prototype.assertChangeAnnotations=function(r){if(r===void 0)throw new Error("Text edit change is not configured to manage change annotations.")},e}(),_t=function(){function e(r){this._annotations=r===void 0?Object.create(null):r,this._counter=0,this._size=0}return e.prototype.all=function(){return this._annotations},Object.defineProperty(e.prototype,"size",{get:function(){return this._size},enumerable:!1,configurable:!0}),e.prototype.manage=function(r,i){var t;if(ee.is(r)?t=r:(t=this.nextId(),i=r),this._annotations[t]!==void 0)throw new Error("Id "+t+" is already in use.");if(i===void 0)throw new Error("No annotation provided for id "+t);return this._annotations[t]=i,this._size++,t},e.prototype.nextId=function(){return this._counter++,this._counter.toString()},e}(),Vn=function(){function e(r){var i=this;this._textEditChanges=Object.create(null),r!==void 0?(this._workspaceEdit=r,r.documentChanges?(this._changeAnnotations=new _t(r.changeAnnotations),r.changeAnnotations=this._changeAnnotations.all(),r.documentChanges.forEach(function(t){if(He.is(t)){var n=new Ge(t.edits,i._changeAnnotations);i._textEditChanges[t.textDocument.uri]=n}})):r.changes&&Object.keys(r.changes).forEach(function(t){var n=new Ge(r.changes[t]);i._textEditChanges[t]=n})):this._workspaceEdit={}}return Object.defineProperty(e.prototype,"edit",{get:function(){return this.initDocumentChanges(),this._changeAnnotations!==void 0&&(this._changeAnnotations.size===0?this._workspaceEdit.changeAnnotations=void 0:this._workspaceEdit.changeAnnotations=this._changeAnnotations.all()),this._workspaceEdit},enumerable:!1,configurable:!0}),e.prototype.getTextEditChange=function(r){if(Xe.is(r)){if(this.initDocumentChanges(),this._workspaceEdit.documentChanges===void 0)throw new Error("Workspace edit is not configured for document changes.");var i={uri:r.uri,version:r.version},t=this._textEditChanges[i.uri];if(!t){var n=[],a={textDocument:i,edits:n};this._workspaceEdit.documentChanges.push(a),t=new Ge(n,this._changeAnnotations),this._textEditChanges[i.uri]=t}return t}else{if(this.initChanges(),this._workspaceEdit.changes===void 0)throw new Error("Workspace edit is not configured for normal text edit changes.");var t=this._textEditChanges[r];if(!t){var n=[];this._workspaceEdit.changes[r]=n,t=new Ge(n),this._textEditChanges[r]=t}return t}},e.prototype.initDocumentChanges=function(){this._workspaceEdit.documentChanges===void 0&&this._workspaceEdit.changes===void 0&&(this._changeAnnotations=new _t,this._workspaceEdit.documentChanges=[],this._workspaceEdit.changeAnnotations=this._changeAnnotations.all())},e.prototype.initChanges=function(){this._workspaceEdit.documentChanges===void 0&&this._workspaceEdit.changes===void 0&&(this._workspaceEdit.changes=Object.create(null))},e.prototype.createFile=function(r,i,t){if(this.initDocumentChanges(),this._workspaceEdit.documentChanges===void 0)throw new Error("Workspace edit is not configured for document changes.");var n;Ee.is(i)||ee.is(i)?n=i:t=i;var a,s;if(n===void 0?a=De.create(r,t):(s=ee.is(n)?n:this._changeAnnotations.manage(n),a=De.create(r,t,s)),this._workspaceEdit.documentChanges.push(a),s!==void 0)return s},e.prototype.renameFile=function(r,i,t,n){if(this.initDocumentChanges(),this._workspaceEdit.documentChanges===void 0)throw new Error("Workspace edit is not configured for document changes.");var a;Ee.is(t)||ee.is(t)?a=t:n=t;var s,o;if(a===void 0?s=We.create(r,i,n):(o=ee.is(a)?a:this._changeAnnotations.manage(a),s=We.create(r,i,n,o)),this._workspaceEdit.documentChanges.push(s),o!==void 0)return o},e.prototype.deleteFile=function(r,i,t){if(this.initDocumentChanges(),this._workspaceEdit.documentChanges===void 0)throw new Error("Workspace edit is not configured for document changes.");var n;Ee.is(i)||ee.is(i)?n=i:t=i;var a,s;if(n===void 0?a=Ue.create(r,t):(s=ee.is(n)?n:this._changeAnnotations.manage(n),a=Ue.create(r,t,s)),this._workspaceEdit.documentChanges.push(a),s!==void 0)return s},e}(),Dt;(function(e){function r(t){return{uri:t}}e.create=r;function i(t){var n=t;return b.defined(n)&&b.string(n.uri)}e.is=i})(Dt||(Dt={}));var Wt;(function(e){function r(t,n){return{uri:t,version:n}}e.create=r;function i(t){var n=t;return b.defined(n)&&b.string(n.uri)&&b.integer(n.version)}e.is=i})(Wt||(Wt={}));var Xe;(function(e){function r(t,n){return{uri:t,version:n}}e.create=r;function i(t){var n=t;return b.defined(n)&&b.string(n.uri)&&(n.version===null||b.integer(n.version))}e.is=i})(Xe||(Xe={}));var Ut;(function(e){function r(t,n,a,s){return{uri:t,languageId:n,version:a,text:s}}e.create=r;function i(t){var n=t;return b.defined(n)&&b.string(n.uri)&&b.string(n.languageId)&&b.integer(n.version)&&b.string(n.text)}e.is=i})(Ut||(Ut={}));var we;(function(e){e.PlainText="plaintext",e.Markdown="markdown"})(we||(we={})),function(e){function r(i){var t=i;return t===e.PlainText||t===e.Markdown}e.is=r}(we||(we={}));var ut;(function(e){function r(i){var t=i;return b.objectLiteral(i)&&we.is(t.kind)&&b.string(t.value)}e.is=r})(ut||(ut={}));var ie;(function(e){e.Text=1,e.Method=2,e.Function=3,e.Constructor=4,e.Field=5,e.Variable=6,e.Class=7,e.Interface=8,e.Module=9,e.Property=10,e.Unit=11,e.Value=12,e.Enum=13,e.Keyword=14,e.Snippet=15,e.Color=16,e.File=17,e.Reference=18,e.Folder=19,e.EnumMember=20,e.Constant=21,e.Struct=22,e.Event=23,e.Operator=24,e.TypeParameter=25})(ie||(ie={}));var Z;(function(e){e.PlainText=1,e.Snippet=2})(Z||(Z={}));var Rt;(function(e){e.Deprecated=1})(Rt||(Rt={}));var qt;(function(e){function r(t,n,a){return{newText:t,insert:n,replace:a}}e.create=r;function i(t){var n=t;return n&&b.string(n.newText)&&J.is(n.insert)&&J.is(n.replace)}e.is=i})(qt||(qt={}));var Jt;(function(e){e.asIs=1,e.adjustIndentation=2})(Jt||(Jt={}));var ct;(function(e){function r(i){return{label:i}}e.create=r})(ct||(ct={}));var zt;(function(e){function r(i,t){return{items:i||[],isIncomplete:!!t}}e.create=r})(zt||(zt={}));var Ze;(function(e){function r(t){return t.replace(/[\\`*_{}[\]()#+\-.!]/g,"\\$&")}e.fromPlainText=r;function i(t){var n=t;return b.string(n)||b.objectLiteral(n)&&b.string(n.language)&&b.string(n.value)}e.is=i})(Ze||(Ze={}));var Bt;(function(e){function r(i){var t=i;return!!t&&b.objectLiteral(t)&&(ut.is(t.contents)||Ze.is(t.contents)||b.typedArray(t.contents,Ze.is))&&(i.range===void 0||J.is(i.range))}e.is=r})(Bt||(Bt={}));var Ht;(function(e){function r(i,t){return t?{label:i,documentation:t}:{label:i}}e.create=r})(Ht||(Ht={}));var Gt;(function(e){function r(i,t){for(var n=[],a=2;a<arguments.length;a++)n[a-2]=arguments[a];var s={label:i};return b.defined(t)&&(s.documentation=t),b.defined(n)?s.parameters=n:s.parameters=[],s}e.create=r})(Gt||(Gt={}));var Xt;(function(e){e.Text=1,e.Read=2,e.Write=3})(Xt||(Xt={}));var Zt;(function(e){function r(i,t){var n={range:i};return b.number(t)&&(n.kind=t),n}e.create=r})(Zt||(Zt={}));var ve;(function(e){e.File=1,e.Module=2,e.Namespace=3,e.Package=4,e.Class=5,e.Method=6,e.Property=7,e.Field=8,e.Constructor=9,e.Enum=10,e.Interface=11,e.Function=12,e.Variable=13,e.Constant=14,e.String=15,e.Number=16,e.Boolean=17,e.Array=18,e.Object=19,e.Key=20,e.Null=21,e.EnumMember=22,e.Struct=23,e.Event=24,e.Operator=25,e.TypeParameter=26})(ve||(ve={}));var Qt;(function(e){e.Deprecated=1})(Qt||(Qt={}));var Yt;(function(e){function r(i,t,n,a,s){var o={name:i,kind:t,location:{uri:a,range:n}};return s&&(o.containerName=s),o}e.create=r})(Yt||(Yt={}));var Kt;(function(e){function r(t,n,a,s,o,f){var l={name:t,detail:n,kind:a,range:s,selectionRange:o};return f!==void 0&&(l.children=f),l}e.create=r;function i(t){var n=t;return n&&b.string(n.name)&&b.number(n.kind)&&J.is(n.range)&&J.is(n.selectionRange)&&(n.detail===void 0||b.string(n.detail))&&(n.deprecated===void 0||b.boolean(n.deprecated))&&(n.children===void 0||Array.isArray(n.children))&&(n.tags===void 0||Array.isArray(n.tags))}e.is=i})(Kt||(Kt={}));var er;(function(e){e.Empty="",e.QuickFix="quickfix",e.Refactor="refactor",e.RefactorExtract="refactor.extract",e.RefactorInline="refactor.inline",e.RefactorRewrite="refactor.rewrite",e.Source="source",e.SourceOrganizeImports="source.organizeImports",e.SourceFixAll="source.fixAll"})(er||(er={}));var tr;(function(e){function r(t,n){var a={diagnostics:t};return n!=null&&(a.only=n),a}e.create=r;function i(t){var n=t;return b.defined(n)&&b.typedArray(n.diagnostics,Se.is)&&(n.only===void 0||b.typedArray(n.only,b.string))}e.is=i})(tr||(tr={}));var rr;(function(e){function r(t,n,a){var s={title:t},o=!0;return typeof n=="string"?(o=!1,s.kind=n):_e.is(n)?s.command=n:s.edit=n,o&&a!==void 0&&(s.kind=a),s}e.create=r;function i(t){var n=t;return n&&b.string(n.title)&&(n.diagnostics===void 0||b.typedArray(n.diagnostics,Se.is))&&(n.kind===void 0||b.string(n.kind))&&(n.edit!==void 0||n.command!==void 0)&&(n.command===void 0||_e.is(n.command))&&(n.isPreferred===void 0||b.boolean(n.isPreferred))&&(n.edit===void 0||ft.is(n.edit))}e.is=i})(rr||(rr={}));var nr;(function(e){function r(t,n){var a={range:t};return b.defined(n)&&(a.data=n),a}e.create=r;function i(t){var n=t;return b.defined(n)&&J.is(n.range)&&(b.undefined(n.command)||_e.is(n.command))}e.is=i})(nr||(nr={}));var ir;(function(e){function r(t,n){return{tabSize:t,insertSpaces:n}}e.create=r;function i(t){var n=t;return b.defined(n)&&b.uinteger(n.tabSize)&&b.boolean(n.insertSpaces)}e.is=i})(ir||(ir={}));var ar;(function(e){function r(t,n,a){return{range:t,target:n,data:a}}e.create=r;function i(t){var n=t;return b.defined(n)&&J.is(n.range)&&(b.undefined(n.target)||b.string(n.target))}e.is=i})(ar||(ar={}));var Qe;(function(e){function r(t,n){return{range:t,parent:n}}e.create=r;function i(t){var n=t;return n!==void 0&&J.is(n.range)&&(n.parent===void 0||e.is(n.parent))}e.is=i})(Qe||(Qe={}));var or;(function(e){function r(a,s,o,f){return new _r(a,s,o,f)}e.create=r;function i(a){var s=a;return!!(b.defined(s)&&b.string(s.uri)&&(b.undefined(s.languageId)||b.string(s.languageId))&&b.uinteger(s.lineCount)&&b.func(s.getText)&&b.func(s.positionAt)&&b.func(s.offsetAt))}e.is=i;function t(a,s){for(var o=a.getText(),f=n(s,function(d,v){var g=d.range.start.line-v.range.start.line;return g===0?d.range.start.character-v.range.start.character:g}),l=o.length,u=f.length-1;u>=0;u--){var c=f[u],h=a.offsetAt(c.range.start),p=a.offsetAt(c.range.end);if(p<=l)o=o.substring(0,h)+c.newText+o.substring(p,o.length);else throw new Error("Overlapping edit");l=h}return o}e.applyEdits=t;function n(a,s){if(a.length<=1)return a;var o=a.length/2|0,f=a.slice(0,o),l=a.slice(o);n(f,s),n(l,s);for(var u=0,c=0,h=0;u<f.length&&c<l.length;){var p=s(f[u],l[c]);p<=0?a[h++]=f[u++]:a[h++]=l[c++]}for(;u<f.length;)a[h++]=f[u++];for(;c<l.length;)a[h++]=l[c++];return a}})(or||(or={}));var _r=function(){function e(r,i,t,n){this._uri=r,this._languageId=i,this._version=t,this._content=n,this._lineOffsets=void 0}return Object.defineProperty(e.prototype,"uri",{get:function(){return this._uri},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"languageId",{get:function(){return this._languageId},enumerable:!1,configurable:!0}),Object.defineProperty(e.prototype,"version",{get:function(){return this._version},enumerable:!1,configurable:!0}),e.prototype.getText=function(r){if(r){var i=this.offsetAt(r.start),t=this.offsetAt(r.end);return this._content.substring(i,t)}return this._content},e.prototype.update=function(r,i){this._content=r.text,this._version=i,this._lineOffsets=void 0},e.prototype.getLineOffsets=function(){if(this._lineOffsets===void 0){for(var r=[],i=this._content,t=!0,n=0;n<i.length;n++){t&&(r.push(n),t=!1);var a=i.charAt(n);t=a==="\r"||a===`
`,a==="\r"&&n+1<i.length&&i.charAt(n+1)===`
`&&n++}t&&i.length>0&&r.push(i.length),this._lineOffsets=r}return this._lineOffsets},e.prototype.positionAt=function(r){r=Math.max(Math.min(r,this._content.length),0);var i=this.getLineOffsets(),t=0,n=i.length;if(n===0)return he.create(0,r);for(;t<n;){var a=Math.floor((t+n)/2);i[a]>r?n=a:t=a+1}var s=t-1;return he.create(s,r-i[s])},e.prototype.offsetAt=function(r){var i=this.getLineOffsets();if(r.line>=i.length)return this._content.length;if(r.line<0)return 0;var t=i[r.line],n=r.line+1<i.length?i[r.line+1]:this._content.length;return Math.max(Math.min(t+r.character,n),t)},Object.defineProperty(e.prototype,"lineCount",{get:function(){return this.getLineOffsets().length},enumerable:!1,configurable:!0}),e}(),b;(function(e){var r=Object.prototype.toString;function i(p){return typeof p<"u"}e.defined=i;function t(p){return typeof p>"u"}e.undefined=t;function n(p){return p===!0||p===!1}e.boolean=n;function a(p){return r.call(p)==="[object String]"}e.string=a;function s(p){return r.call(p)==="[object Number]"}e.number=s;function o(p,d,v){return r.call(p)==="[object Number]"&&d<=p&&p<=v}e.numberRange=o;function f(p){return r.call(p)==="[object Number]"&&-2147483648<=p&&p<=2147483647}e.integer=f;function l(p){return r.call(p)==="[object Number]"&&0<=p&&p<=2147483647}e.uinteger=l;function u(p){return r.call(p)==="[object Function]"}e.func=u;function c(p){return p!==null&&typeof p=="object"}e.objectLiteral=c;function h(p,d){return Array.isArray(p)&&p.every(d)}e.typedArray=h})(b||(b={}));var Ye=class{constructor(e,r,i,t){this._uri=e,this._languageId=r,this._version=i,this._content=t,this._lineOffsets=void 0}get uri(){return this._uri}get languageId(){return this._languageId}get version(){return this._version}getText(e){if(e){const r=this.offsetAt(e.start),i=this.offsetAt(e.end);return this._content.substring(r,i)}return this._content}update(e,r){for(let i of e)if(Ye.isIncremental(i)){const t=fr(i.range),n=this.offsetAt(t.start),a=this.offsetAt(t.end);this._content=this._content.substring(0,n)+i.text+this._content.substring(a,this._content.length);const s=Math.max(t.start.line,0),o=Math.max(t.end.line,0);let f=this._lineOffsets;const l=sr(i.text,!1,n);if(o-s===l.length)for(let c=0,h=l.length;c<h;c++)f[c+s+1]=l[c];else l.length<1e4?f.splice(s+1,o-s,...l):this._lineOffsets=f=f.slice(0,s+1).concat(l,f.slice(o+1));const u=i.text.length-(a-n);if(u!==0)for(let c=s+1+l.length,h=f.length;c<h;c++)f[c]=f[c]+u}else if(Ye.isFull(i))this._content=i.text,this._lineOffsets=void 0;else throw new Error("Unknown change event received");this._version=r}getLineOffsets(){return this._lineOffsets===void 0&&(this._lineOffsets=sr(this._content,!0)),this._lineOffsets}positionAt(e){e=Math.max(Math.min(e,this._content.length),0);let r=this.getLineOffsets(),i=0,t=r.length;if(t===0)return{line:0,character:e};for(;i<t;){let a=Math.floor((i+t)/2);r[a]>e?t=a:i=a+1}let n=i-1;return{line:n,character:e-r[n]}}offsetAt(e){let r=this.getLineOffsets();if(e.line>=r.length)return this._content.length;if(e.line<0)return 0;let i=r[e.line],t=e.line+1<r.length?r[e.line+1]:this._content.length;return Math.max(Math.min(i+e.character,t),i)}get lineCount(){return this.getLineOffsets().length}static isIncremental(e){let r=e;return r!=null&&typeof r.text=="string"&&r.range!==void 0&&(r.rangeLength===void 0||typeof r.rangeLength=="number")}static isFull(e){let r=e;return r!=null&&typeof r.text=="string"&&r.range===void 0&&r.rangeLength===void 0}},lt;(function(e){function r(n,a,s,o){return new Ye(n,a,s,o)}e.create=r;function i(n,a,s){if(n instanceof Ye)return n.update(a,s),n;throw new Error("TextDocument.update: document must be created by TextDocument.create")}e.update=i;function t(n,a){let s=n.getText(),o=ht(a.map(Dr),(u,c)=>{let h=u.range.start.line-c.range.start.line;return h===0?u.range.start.character-c.range.start.character:h}),f=0;const l=[];for(const u of o){let c=n.offsetAt(u.range.start);if(c<f)throw new Error("Overlapping edit");c>f&&l.push(s.substring(f,c)),u.newText.length&&l.push(u.newText),f=n.offsetAt(u.range.end)}return l.push(s.substr(f)),l.join("")}e.applyEdits=t})(lt||(lt={}));function ht(e,r){if(e.length<=1)return e;const i=e.length/2|0,t=e.slice(0,i),n=e.slice(i);ht(t,r),ht(n,r);let a=0,s=0,o=0;for(;a<t.length&&s<n.length;)r(t[a],n[s])<=0?e[o++]=t[a++]:e[o++]=n[s++];for(;a<t.length;)e[o++]=t[a++];for(;s<n.length;)e[o++]=n[s++];return e}function sr(e,r,i=0){const t=r?[i]:[];for(let n=0;n<e.length;n++){let a=e.charCodeAt(n);(a===13||a===10)&&(a===13&&n+1<e.length&&e.charCodeAt(n+1)===10&&n++,t.push(i+n+1))}return t}function fr(e){const r=e.start,i=e.end;return r.line>i.line||r.line===i.line&&r.character>i.character?{start:i,end:r}:e}function Dr(e){const r=fr(e.range);return r!==e.range?{newText:e.newText,range:r}:e}var U;(function(e){e[e.Undefined=0]="Undefined",e[e.EnumValueMismatch=1]="EnumValueMismatch",e[e.Deprecated=2]="Deprecated",e[e.UnexpectedEndOfComment=257]="UnexpectedEndOfComment",e[e.UnexpectedEndOfString=258]="UnexpectedEndOfString",e[e.UnexpectedEndOfNumber=259]="UnexpectedEndOfNumber",e[e.InvalidUnicode=260]="InvalidUnicode",e[e.InvalidEscapeCharacter=261]="InvalidEscapeCharacter",e[e.InvalidCharacter=262]="InvalidCharacter",e[e.PropertyExpected=513]="PropertyExpected",e[e.CommaExpected=514]="CommaExpected",e[e.ColonExpected=515]="ColonExpected",e[e.ValueExpected=516]="ValueExpected",e[e.CommaOrCloseBacketExpected=517]="CommaOrCloseBacketExpected",e[e.CommaOrCloseBraceExpected=518]="CommaOrCloseBraceExpected",e[e.TrailingComma=519]="TrailingComma",e[e.DuplicateKey=520]="DuplicateKey",e[e.CommentNotPermitted=521]="CommentNotPermitted",e[e.SchemaResolveError=768]="SchemaResolveError"})(U||(U={}));var ur;(function(e){e.LATEST={textDocument:{completion:{completionItem:{documentationFormat:[we.Markdown,we.PlainText],commitCharactersSupport:!0}}}}})(ur||(ur={}));function Wr(e,r){let i;return r.length===0?i=e:i=e.replace(/\{(\d+)\}/g,(t,n)=>{let a=n[0];return typeof r[a]<"u"?r[a]:t}),i}function Ur(e,r,...i){return Wr(r,i)}function Re(e){return Ur}var Oe=function(){var e=function(r,i){return e=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(t,n){t.__proto__=n}||function(t,n){for(var a in n)Object.prototype.hasOwnProperty.call(n,a)&&(t[a]=n[a])},e(r,i)};return function(r,i){if(typeof i!="function"&&i!==null)throw new TypeError("Class extends value "+String(i)+" is not a constructor or null");e(r,i);function t(){this.constructor=r}r.prototype=i===null?Object.create(i):(t.prototype=i.prototype,new t)}}(),M=Re(),Rr={"color-hex":{errorMessage:M("colorHexFormatWarning","Invalid color format. Use #RGB, #RGBA, #RRGGBB or #RRGGBBAA."),pattern:/^#([0-9A-Fa-f]{3,4}|([0-9A-Fa-f]{2}){3,4})$/},"date-time":{errorMessage:M("dateTimeFormatWarning","String is not a RFC3339 date-time."),pattern:/^(\d{4})-(0[1-9]|1[0-2])-(0[1-9]|[12][0-9]|3[01])T([01][0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9]|60)(\.[0-9]+)?(Z|(\+|-)([01][0-9]|2[0-3]):([0-5][0-9]))$/i},date:{errorMessage:M("dateFormatWarning","String is not a RFC3339 date."),pattern:/^(\d{4})-(0[1-9]|1[0-2])-(0[1-9]|[12][0-9]|3[01])$/i},time:{errorMessage:M("timeFormatWarning","String is not a RFC3339 time."),pattern:/^([01][0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9]|60)(\.[0-9]+)?(Z|(\+|-)([01][0-9]|2[0-3]):([0-5][0-9]))$/i},email:{errorMessage:M("emailFormatWarning","String is not an e-mail address."),pattern:/^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z0-9-]+\.)+[a-zA-Z]{2,}))$/},hostname:{errorMessage:M("hostnameFormatWarning","String is not a hostname."),pattern:/^(?=.{1,253}\.?$)[a-z0-9](?:[a-z0-9-]{0,61}[a-z0-9])?(?:\.[a-z0-9](?:[-0-9a-z]{0,61}[0-9a-z])?)*\.?$/i},ipv4:{errorMessage:M("ipv4FormatWarning","String is not an IPv4 address."),pattern:/^(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)\.){3}(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)$/},ipv6:{errorMessage:M("ipv6FormatWarning","String is not an IPv6 address."),pattern:/^((([0-9a-f]{1,4}:){7}([0-9a-f]{1,4}|:))|(([0-9a-f]{1,4}:){6}(:[0-9a-f]{1,4}|((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(([0-9a-f]{1,4}:){5}(((:[0-9a-f]{1,4}){1,2})|:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3})|:))|(([0-9a-f]{1,4}:){4}(((:[0-9a-f]{1,4}){1,3})|((:[0-9a-f]{1,4})?:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9a-f]{1,4}:){3}(((:[0-9a-f]{1,4}){1,4})|((:[0-9a-f]{1,4}){0,2}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9a-f]{1,4}:){2}(((:[0-9a-f]{1,4}){1,5})|((:[0-9a-f]{1,4}){0,3}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(([0-9a-f]{1,4}:){1}(((:[0-9a-f]{1,4}){1,6})|((:[0-9a-f]{1,4}){0,4}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:))|(:(((:[0-9a-f]{1,4}){1,7})|((:[0-9a-f]{1,4}){0,5}:((25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)(\.(25[0-5]|2[0-4]\d|1\d\d|[1-9]?\d)){3}))|:)))$/i}},Ce=function(){function e(r,i,t){t===void 0&&(t=0),this.offset=i,this.length=t,this.parent=r}return Object.defineProperty(e.prototype,"children",{get:function(){return[]},enumerable:!1,configurable:!0}),e.prototype.toString=function(){return"type: "+this.type+" ("+this.offset+"/"+this.length+")"+(this.parent?" parent: {"+this.parent.toString()+"}":"")},e}(),qr=function(e){Oe(r,e);function r(i,t){var n=e.call(this,i,t)||this;return n.type="null",n.value=null,n}return r}(Ce),cr=function(e){Oe(r,e);function r(i,t,n){var a=e.call(this,i,n)||this;return a.type="boolean",a.value=t,a}return r}(Ce),Jr=function(e){Oe(r,e);function r(i,t){var n=e.call(this,i,t)||this;return n.type="array",n.items=[],n}return Object.defineProperty(r.prototype,"children",{get:function(){return this.items},enumerable:!1,configurable:!0}),r}(Ce),zr=function(e){Oe(r,e);function r(i,t){var n=e.call(this,i,t)||this;return n.type="number",n.isInteger=!0,n.value=Number.NaN,n}return r}(Ce),gt=function(e){Oe(r,e);function r(i,t,n){var a=e.call(this,i,t,n)||this;return a.type="string",a.value="",a}return r}(Ce),Br=function(e){Oe(r,e);function r(i,t,n){var a=e.call(this,i,t)||this;return a.type="property",a.colonOffset=-1,a.keyNode=n,a}return Object.defineProperty(r.prototype,"children",{get:function(){return this.valueNode?[this.keyNode,this.valueNode]:[this.keyNode]},enumerable:!1,configurable:!0}),r}(Ce),Hr=function(e){Oe(r,e);function r(i,t){var n=e.call(this,i,t)||this;return n.type="object",n.properties=[],n}return Object.defineProperty(r.prototype,"children",{get:function(){return this.properties},enumerable:!1,configurable:!0}),r}(Ce);function ae(e){return pe(e)?e?{}:{not:{}}:e}var lr;(function(e){e[e.Key=0]="Key",e[e.Enum=1]="Enum"})(lr||(lr={}));var Gr=function(){function e(r,i){r===void 0&&(r=-1),this.focusOffset=r,this.exclude=i,this.schemas=[]}return e.prototype.add=function(r){this.schemas.push(r)},e.prototype.merge=function(r){Array.prototype.push.apply(this.schemas,r.schemas)},e.prototype.include=function(r){return(this.focusOffset===-1||hr(r,this.focusOffset))&&r!==this.exclude},e.prototype.newSub=function(){return new e(-1,this.exclude)},e}(),pt=function(){function e(){}return Object.defineProperty(e.prototype,"schemas",{get:function(){return[]},enumerable:!1,configurable:!0}),e.prototype.add=function(r){},e.prototype.merge=function(r){},e.prototype.include=function(r){return!0},e.prototype.newSub=function(){return this},e.instance=new e,e}(),oe=function(){function e(){this.problems=[],this.propertiesMatches=0,this.propertiesValueMatches=0,this.primaryValueMatches=0,this.enumValueMatch=!1,this.enumValues=void 0}return e.prototype.hasProblems=function(){return!!this.problems.length},e.prototype.mergeAll=function(r){for(var i=0,t=r;i<t.length;i++){var n=t[i];this.merge(n)}},e.prototype.merge=function(r){this.problems=this.problems.concat(r.problems)},e.prototype.mergeEnumValues=function(r){if(!this.enumValueMatch&&!r.enumValueMatch&&this.enumValues&&r.enumValues){this.enumValues=this.enumValues.concat(r.enumValues);for(var i=0,t=this.problems;i<t.length;i++){var n=t[i];n.code===U.EnumValueMismatch&&(n.message=M("enumWarning","Value is not accepted. Valid values: {0}.",this.enumValues.map(function(a){return JSON.stringify(a)}).join(", ")))}}},e.prototype.mergePropertyMatch=function(r){this.merge(r),this.propertiesMatches++,(r.enumValueMatch||!r.hasProblems()&&r.propertiesMatches)&&this.propertiesValueMatches++,r.enumValueMatch&&r.enumValues&&r.enumValues.length===1&&this.primaryValueMatches++},e.prototype.compare=function(r){var i=this.hasProblems();return i!==r.hasProblems()?i?-1:1:this.enumValueMatch!==r.enumValueMatch?r.enumValueMatch?-1:1:this.primaryValueMatches!==r.primaryValueMatches?this.primaryValueMatches-r.primaryValueMatches:this.propertiesValueMatches!==r.propertiesValueMatches?this.propertiesValueMatches-r.propertiesValueMatches:this.propertiesMatches-r.propertiesMatches},e}();function Xr(e,r){return r===void 0&&(r=[]),new gr(e,r,[])}function je(e){return Fr(e)}function vt(e){return Mr(e)}function hr(e,r,i){return i===void 0&&(i=!1),r>=e.offset&&r<e.offset+e.length||i&&r===e.offset+e.length}var gr=function(){function e(r,i,t){i===void 0&&(i=[]),t===void 0&&(t=[]),this.root=r,this.syntaxErrors=i,this.comments=t}return e.prototype.getNodeFromOffset=function(r,i){if(i===void 0&&(i=!1),this.root)return Nr(this.root,r,i)},e.prototype.visit=function(r){if(this.root){var i=function(t){var n=r(t),a=t.children;if(Array.isArray(a))for(var s=0;s<a.length&&n;s++)n=i(a[s]);return n};i(this.root)}},e.prototype.validate=function(r,i,t){if(t===void 0&&(t=fe.Warning),this.root&&i){var n=new oe;return Y(this.root,i,n,pt.instance),n.problems.map(function(a){var s,o=J.create(r.positionAt(a.location.offset),r.positionAt(a.location.offset+a.location.length));return Se.create(o,a.message,(s=a.severity)!==null&&s!==void 0?s:t,a.code)})}},e.prototype.getMatchingSchemas=function(r,i,t){i===void 0&&(i=-1);var n=new Gr(i,t);return this.root&&r&&Y(this.root,r,new oe,n),n.schemas},e}();function Y(e,r,i,t){if(!e||!t.include(e))return;var n=e;switch(n.type){case"object":l(n,r,i,t);break;case"array":f(n,r,i,t);break;case"string":o(n,r,i,t);break;case"number":s(n,r,i,t);break;case"property":return Y(n.valueNode,r,i,t)}a(),t.add({node:n,schema:r});function a(){function u(V){return n.type===V||V==="integer"&&n.type==="number"&&n.isInteger}if(Array.isArray(r.type)?r.type.some(u)||i.problems.push({location:{offset:n.offset,length:n.length},message:r.errorMessage||M("typeArrayMismatchWarning","Incorrect type. Expected one of {0}.",r.type.join(", "))}):r.type&&(u(r.type)||i.problems.push({location:{offset:n.offset,length:n.length},message:r.errorMessage||M("typeMismatchWarning",'Incorrect type. Expected "{0}".',r.type)})),Array.isArray(r.allOf))for(var c=0,h=r.allOf;c<h.length;c++){var p=h[c];Y(n,ae(p),i,t)}var d=ae(r.not);if(d){var v=new oe,g=t.newSub();Y(n,d,v,g),v.hasProblems()||i.problems.push({location:{offset:n.offset,length:n.length},message:M("notSchemaWarning","Matches a schema that is not allowed.")});for(var A=0,y=g.schemas;A<y.length;A++){var m=y[A];m.inverted=!m.inverted,t.add(m)}}var O=function(V,D){for(var te=[],z=void 0,k=0,S=V;k<S.length;k++){var T=S[k],I=ae(T),L=new oe,_=t.newSub();if(Y(n,I,L,_),L.hasProblems()||te.push(I),!z)z={schema:I,validationResult:L,matchingSchemas:_};else if(!D&&!L.hasProblems()&&!z.validationResult.hasProblems())z.matchingSchemas.merge(_),z.validationResult.propertiesMatches+=L.propertiesMatches,z.validationResult.propertiesValueMatches+=L.propertiesValueMatches;else{var R=L.compare(z.validationResult);R>0?z={schema:I,validationResult:L,matchingSchemas:_}:R===0&&(z.matchingSchemas.merge(_),z.validationResult.mergeEnumValues(L))}}return te.length>1&&D&&i.problems.push({location:{offset:n.offset,length:1},message:M("oneOfWarning","Matches multiple schemas when only one must validate.")}),z&&(i.merge(z.validationResult),i.propertiesMatches+=z.validationResult.propertiesMatches,i.propertiesValueMatches+=z.validationResult.propertiesValueMatches,t.merge(z.matchingSchemas)),te.length};Array.isArray(r.anyOf)&&O(r.anyOf,!1),Array.isArray(r.oneOf)&&O(r.oneOf,!0);var E=function(V){var D=new oe,te=t.newSub();Y(n,ae(V),D,te),i.merge(D),i.propertiesMatches+=D.propertiesMatches,i.propertiesValueMatches+=D.propertiesValueMatches,t.merge(te)},P=function(V,D,te){var z=ae(V),k=new oe,S=t.newSub();Y(n,z,k,S),t.merge(S),k.hasProblems()?te&&E(te):D&&E(D)},w=ae(r.if);if(w&&P(w,ae(r.then),ae(r.else)),Array.isArray(r.enum)){for(var j=je(n),x=!1,C=0,F=r.enum;C<F.length;C++){var N=F[C];if(Fe(j,N)){x=!0;break}}i.enumValues=r.enum,i.enumValueMatch=x,x||i.problems.push({location:{offset:n.offset,length:n.length},code:U.EnumValueMismatch,message:r.errorMessage||M("enumWarning","Value is not accepted. Valid values: {0}.",r.enum.map(function(V){return JSON.stringify(V)}).join(", "))})}if(Ae(r.const)){var j=je(n);Fe(j,r.const)?i.enumValueMatch=!0:(i.problems.push({location:{offset:n.offset,length:n.length},code:U.EnumValueMismatch,message:r.errorMessage||M("constWarning","Value must be {0}.",JSON.stringify(r.const))}),i.enumValueMatch=!1),i.enumValues=[r.const]}r.deprecationMessage&&n.parent&&i.problems.push({location:{offset:n.parent.offset,length:n.parent.length},severity:fe.Warning,message:r.deprecationMessage,code:U.Deprecated})}function s(u,c,h,p){var d=u.value;function v(C){var F,N=/^(-?\d+)(?:\.(\d+))?(?:e([-+]\d+))?$/.exec(C.toString());return N&&{value:Number(N[1]+(N[2]||"")),multiplier:(((F=N[2])===null||F===void 0?void 0:F.length)||0)-(parseInt(N[3])||0)}}if(se(c.multipleOf)){var g=-1;if(Number.isInteger(c.multipleOf))g=d%c.multipleOf;else{var A=v(c.multipleOf),y=v(d);if(A&&y){var m=Math.pow(10,Math.abs(y.multiplier-A.multiplier));y.multiplier<A.multiplier?y.value*=m:A.value*=m,g=y.value%A.value}}g!==0&&h.problems.push({location:{offset:u.offset,length:u.length},message:M("multipleOfWarning","Value is not divisible by {0}.",c.multipleOf)})}function O(C,F){if(se(F))return F;if(pe(F)&&F)return C}function E(C,F){if(!pe(F)||!F)return C}var P=O(c.minimum,c.exclusiveMinimum);se(P)&&d<=P&&h.problems.push({location:{offset:u.offset,length:u.length},message:M("exclusiveMinimumWarning","Value is below the exclusive minimum of {0}.",P)});var w=O(c.maximum,c.exclusiveMaximum);se(w)&&d>=w&&h.problems.push({location:{offset:u.offset,length:u.length},message:M("exclusiveMaximumWarning","Value is above the exclusive maximum of {0}.",w)});var j=E(c.minimum,c.exclusiveMinimum);se(j)&&d<j&&h.problems.push({location:{offset:u.offset,length:u.length},message:M("minimumWarning","Value is below the minimum of {0}.",j)});var x=E(c.maximum,c.exclusiveMaximum);se(x)&&d>x&&h.problems.push({location:{offset:u.offset,length:u.length},message:M("maximumWarning","Value is above the maximum of {0}.",x)})}function o(u,c,h,p){if(se(c.minLength)&&u.value.length<c.minLength&&h.problems.push({location:{offset:u.offset,length:u.length},message:M("minLengthWarning","String is shorter than the minimum length of {0}.",c.minLength)}),se(c.maxLength)&&u.value.length>c.maxLength&&h.problems.push({location:{offset:u.offset,length:u.length},message:M("maxLengthWarning","String is longer than the maximum length of {0}.",c.maxLength)}),Lr(c.pattern)){var d=ze(c.pattern);d?.test(u.value)||h.problems.push({location:{offset:u.offset,length:u.length},message:c.patternErrorMessage||c.errorMessage||M("patternWarning",'String does not match the pattern of "{0}".',c.pattern)})}if(c.format)switch(c.format){case"uri":case"uri-reference":{var v=void 0;if(!u.value)v=M("uriEmpty","URI expected.");else{var g=/^(([^:/?#]+?):)?(\/\/([^/?#]*))?([^?#]*)(\?([^#]*))?(#(.*))?/.exec(u.value);g?!g[2]&&c.format==="uri"&&(v=M("uriSchemeMissing","URI with a scheme is expected.")):v=M("uriMissing","URI is expected.")}v&&h.problems.push({location:{offset:u.offset,length:u.length},message:c.patternErrorMessage||c.errorMessage||M("uriFormatWarning","String is not a URI: {0}",v)})}break;case"color-hex":case"date-time":case"date":case"time":case"email":case"hostname":case"ipv4":case"ipv6":var A=Rr[c.format];(!u.value||!A.pattern.exec(u.value))&&h.problems.push({location:{offset:u.offset,length:u.length},message:c.patternErrorMessage||c.errorMessage||A.errorMessage});default:}}function f(u,c,h,p){if(Array.isArray(c.items)){for(var d=c.items,v=0;v<d.length;v++){var g=d[v],A=ae(g),y=new oe,m=u.items[v];m?(Y(m,A,y,p),h.mergePropertyMatch(y)):u.items.length>=d.length&&h.propertiesValueMatches++}if(u.items.length>d.length)if(typeof c.additionalItems=="object")for(var O=d.length;O<u.items.length;O++){var y=new oe;Y(u.items[O],c.additionalItems,y,p),h.mergePropertyMatch(y)}else c.additionalItems===!1&&h.problems.push({location:{offset:u.offset,length:u.length},message:M("additionalItemsWarning","Array has too many items according to schema. Expected {0} or fewer.",d.length)})}else{var E=ae(c.items);if(E)for(var P=0,w=u.items;P<w.length;P++){var m=w[P],y=new oe;Y(m,E,y,p),h.mergePropertyMatch(y)}}var j=ae(c.contains);if(j){var x=u.items.some(function(N){var V=new oe;return Y(N,j,V,pt.instance),!V.hasProblems()});x||h.problems.push({location:{offset:u.offset,length:u.length},message:c.errorMessage||M("requiredItemMissingWarning","Array does not contain required item.")})}if(se(c.minItems)&&u.items.length<c.minItems&&h.problems.push({location:{offset:u.offset,length:u.length},message:M("minItemsWarning","Array has too few items. Expected {0} or more.",c.minItems)}),se(c.maxItems)&&u.items.length>c.maxItems&&h.problems.push({location:{offset:u.offset,length:u.length},message:M("maxItemsWarning","Array has too many items. Expected {0} or fewer.",c.maxItems)}),c.uniqueItems===!0){var C=je(u),F=C.some(function(N,V){return V!==C.lastIndexOf(N)});F&&h.problems.push({location:{offset:u.offset,length:u.length},message:M("uniqueItemsWarning","Array has duplicate items.")})}}function l(u,c,h,p){for(var d=Object.create(null),v=[],g=0,A=u.properties;g<A.length;g++){var y=A[g],m=y.keyNode.value;d[m]=y.valueNode,v.push(m)}if(Array.isArray(c.required))for(var O=0,E=c.required;O<E.length;O++){var P=E[O];if(!d[P]){var w=u.parent&&u.parent.type==="property"&&u.parent.keyNode,j=w?{offset:w.offset,length:w.length}:{offset:u.offset,length:1};h.problems.push({location:j,message:M("MissingRequiredPropWarning",'Missing property "{0}".',P)})}}var x=function(Or){for(var Tt=v.indexOf(Or);Tt>=0;)v.splice(Tt,1),Tt=v.indexOf(Or)};if(c.properties)for(var C=0,F=Object.keys(c.properties);C<F.length;C++){var P=F[C];x(P);var N=c.properties[P],V=d[P];if(V)if(pe(N))if(N)h.propertiesMatches++,h.propertiesValueMatches++;else{var y=V.parent;h.problems.push({location:{offset:y.keyNode.offset,length:y.keyNode.length},message:c.errorMessage||M("DisallowedExtraPropWarning","Property {0} is not allowed.",P)})}else{var D=new oe;Y(V,N,D,p),h.mergePropertyMatch(D)}}if(c.patternProperties)for(var te=0,z=Object.keys(c.patternProperties);te<z.length;te++)for(var k=z[te],S=ze(k),T=0,I=v.slice(0);T<I.length;T++){var P=I[T];if(S?.test(P)){x(P);var V=d[P];if(V){var N=c.patternProperties[k];if(pe(N))if(N)h.propertiesMatches++,h.propertiesValueMatches++;else{var y=V.parent;h.problems.push({location:{offset:y.keyNode.offset,length:y.keyNode.length},message:c.errorMessage||M("DisallowedExtraPropWarning","Property {0} is not allowed.",P)})}else{var D=new oe;Y(V,N,D,p),h.mergePropertyMatch(D)}}}}if(typeof c.additionalProperties=="object")for(var L=0,_=v;L<_.length;L++){var P=_[L],V=d[P];if(V){var D=new oe;Y(V,c.additionalProperties,D,p),h.mergePropertyMatch(D)}}else if(c.additionalProperties===!1&&v.length>0)for(var R=0,me=v;R<me.length;R++){var P=me[R],V=d[P];if(V){var y=V.parent;h.problems.push({location:{offset:y.keyNode.offset,length:y.keyNode.length},message:c.errorMessage||M("DisallowedExtraPropWarning","Property {0} is not allowed.",P)})}}if(se(c.maxProperties)&&u.properties.length>c.maxProperties&&h.problems.push({location:{offset:u.offset,length:u.length},message:M("MaxPropWarning","Object has more properties than limit of {0}.",c.maxProperties)}),se(c.minProperties)&&u.properties.length<c.minProperties&&h.problems.push({location:{offset:u.offset,length:u.length},message:M("MinPropWarning","Object has fewer properties than the required number of {0}",c.minProperties)}),c.dependencies)for(var re=0,le=Object.keys(c.dependencies);re<le.length;re++){var m=le[re],Me=d[m];if(Me){var ye=c.dependencies[m];if(Array.isArray(ye))for(var xt=0,wr=ye;xt<wr.length;xt++){var xr=wr[xt];d[xr]?h.propertiesValueMatches++:h.problems.push({location:{offset:u.offset,length:u.length},message:M("RequiredDependentPropWarning","Object is missing property {0} required by property {1}.",xr,m)})}else{var N=ae(ye);if(N){var D=new oe;Y(u,N,D,p),h.mergePropertyMatch(D)}}}}var kr=ae(c.propertyNames);if(kr)for(var kt=0,Tr=u.properties;kt<Tr.length;kt++){var Mn=Tr[kt],m=Mn.keyNode;m&&Y(m,kr,h,pt.instance)}}}function Zr(e,r){var i=[],t=-1,n=e.getText(),a=Ie(n,!1),s=r&&r.collectComments?[]:void 0;function o(){for(;;){var w=a.scan();switch(c(),w){case 12:case 13:Array.isArray(s)&&s.push(J.create(e.positionAt(a.getTokenOffset()),e.positionAt(a.getTokenOffset()+a.getTokenLength())));break;case 15:case 14:break;default:return w}}}function f(w){return a.getToken()===w?(o(),!0):!1}function l(w,j,x,C,F){if(F===void 0&&(F=fe.Error),i.length===0||x!==t){var N=J.create(e.positionAt(x),e.positionAt(C));i.push(Se.create(N,w,F,j,e.languageId)),t=x}}function u(w,j,x,C,F){x===void 0&&(x=void 0),C===void 0&&(C=[]),F===void 0&&(F=[]);var N=a.getTokenOffset(),V=a.getTokenOffset()+a.getTokenLength();if(N===V&&N>0){for(N--;N>0&&/\s/.test(n.charAt(N));)N--;V=N+1}if(l(w,j,N,V),x&&h(x,!1),C.length+F.length>0)for(var D=a.getToken();D!==17;){if(C.indexOf(D)!==-1){o();break}else if(F.indexOf(D)!==-1)break;D=o()}return x}function c(){switch(a.getTokenError()){case 4:return u(M("InvalidUnicode","Invalid unicode sequence in string."),U.InvalidUnicode),!0;case 5:return u(M("InvalidEscapeCharacter","Invalid escape character in string."),U.InvalidEscapeCharacter),!0;case 3:return u(M("UnexpectedEndOfNumber","Unexpected end of number."),U.UnexpectedEndOfNumber),!0;case 1:return u(M("UnexpectedEndOfComment","Unexpected end of comment."),U.UnexpectedEndOfComment),!0;case 2:return u(M("UnexpectedEndOfString","Unexpected end of string."),U.UnexpectedEndOfString),!0;case 6:return u(M("InvalidCharacter","Invalid characters in string. Control characters must be escaped."),U.InvalidCharacter),!0}return!1}function h(w,j){return w.length=a.getTokenOffset()+a.getTokenLength()-w.offset,j&&o(),w}function p(w){if(a.getToken()===3){var j=new Jr(w,a.getTokenOffset());o();for(var x=0,C=!1;a.getToken()!==4&&a.getToken()!==17;){if(a.getToken()===5){C||u(M("ValueExpected","Value expected"),U.ValueExpected);var F=a.getTokenOffset();if(o(),a.getToken()===4){C&&l(M("TrailingComma","Trailing comma"),U.TrailingComma,F,F+1);continue}}else C&&u(M("ExpectedComma","Expected comma"),U.CommaExpected);var N=O(j);N?j.items.push(N):u(M("PropertyExpected","Value expected"),U.ValueExpected,void 0,[],[4,5]),C=!0}return a.getToken()!==4?u(M("ExpectedCloseBracket","Expected comma or closing bracket"),U.CommaOrCloseBacketExpected,j):h(j,!0)}}var d=new gt(void 0,0,0);function v(w,j){var x=new Br(w,a.getTokenOffset(),d),C=A(x);if(!C)if(a.getToken()===16){u(M("DoubleQuotesExpected","Property keys must be doublequoted"),U.Undefined);var F=new gt(x,a.getTokenOffset(),a.getTokenLength());F.value=a.getTokenValue(),C=F,o()}else return;x.keyNode=C;var N=j[C.value];if(N?(l(M("DuplicateKeyWarning","Duplicate object key"),U.DuplicateKey,x.keyNode.offset,x.keyNode.offset+x.keyNode.length,fe.Warning),typeof N=="object"&&l(M("DuplicateKeyWarning","Duplicate object key"),U.DuplicateKey,N.keyNode.offset,N.keyNode.offset+N.keyNode.length,fe.Warning),j[C.value]=!0):j[C.value]=x,a.getToken()===6)x.colonOffset=a.getTokenOffset(),o();else if(u(M("ColonExpected","Colon expected"),U.ColonExpected),a.getToken()===10&&e.positionAt(C.offset+C.length).line<e.positionAt(a.getTokenOffset()).line)return x.length=C.length,x;var V=O(x);return V?(x.valueNode=V,x.length=V.offset+V.length-x.offset,x):u(M("ValueExpected","Value expected"),U.ValueExpected,x,[],[2,5])}function g(w){if(a.getToken()===1){var j=new Hr(w,a.getTokenOffset()),x=Object.create(null);o();for(var C=!1;a.getToken()!==2&&a.getToken()!==17;){if(a.getToken()===5){C||u(M("PropertyExpected","Property expected"),U.PropertyExpected);var F=a.getTokenOffset();if(o(),a.getToken()===2){C&&l(M("TrailingComma","Trailing comma"),U.TrailingComma,F,F+1);continue}}else C&&u(M("ExpectedComma","Expected comma"),U.CommaExpected);var N=v(j,x);N?j.properties.push(N):u(M("PropertyExpected","Property expected"),U.PropertyExpected,void 0,[],[2,5]),C=!0}return a.getToken()!==2?u(M("ExpectedCloseBrace","Expected comma or closing brace"),U.CommaOrCloseBraceExpected,j):h(j,!0)}}function A(w){if(a.getToken()===10){var j=new gt(w,a.getTokenOffset());return j.value=a.getTokenValue(),h(j,!0)}}function y(w){if(a.getToken()===11){var j=new zr(w,a.getTokenOffset());if(a.getTokenError()===0){var x=a.getTokenValue();try{var C=JSON.parse(x);if(!se(C))return u(M("InvalidNumberFormat","Invalid number format."),U.Undefined,j);j.value=C}catch{return u(M("InvalidNumberFormat","Invalid number format."),U.Undefined,j)}j.isInteger=x.indexOf(".")===-1}return h(j,!0)}}function m(w){var j;switch(a.getToken()){case 7:return h(new qr(w,a.getTokenOffset()),!0);case 8:return h(new cr(w,!0,a.getTokenOffset()),!0);case 9:return h(new cr(w,!1,a.getTokenOffset()),!0);default:return}}function O(w){return p(w)||g(w)||A(w)||y(w)||m(w)}var E=void 0,P=o();return P!==17&&(E=O(E),E?a.getToken()!==17&&u(M("End of file expected","End of file expected."),U.Undefined):u(M("Invalid symbol","Expected a JSON object, array or literal."),U.Undefined)),new gr(E,i,s)}function dt(e,r,i){if(e!==null&&typeof e=="object"){var t=r+"	";if(Array.isArray(e)){if(e.length===0)return"[]";for(var n=`[
`,a=0;a<e.length;a++)n+=t+dt(e[a],t,i),a<e.length-1&&(n+=","),n+=`
`;return n+=r+"]",n}else{var s=Object.keys(e);if(s.length===0)return"{}";for(var n=`{
`,a=0;a<s.length;a++){var o=s[a];n+=t+JSON.stringify(o)+": "+dt(e[o],t,i),a<s.length-1&&(n+=","),n+=`
`}return n+=r+"}",n}}return i(e)}var mt=Re(),Qr=[",","}","]"],Yr=[":"],Kr=function(){function e(r,i,t,n){i===void 0&&(i=[]),t===void 0&&(t=Promise),n===void 0&&(n={}),this.schemaService=r,this.contributions=i,this.promiseConstructor=t,this.clientCapabilities=n}return e.prototype.doResolve=function(r){for(var i=this.contributions.length-1;i>=0;i--){var t=this.contributions[i].resolveCompletion;if(t){var n=t(r);if(n)return n}}return this.promiseConstructor.resolve(r)},e.prototype.doComplete=function(r,i,t){var n=this,a={items:[],isIncomplete:!1},s=r.getText(),o=r.offsetAt(i),f=t.getNodeFromOffset(o,!0);if(this.isInComment(r,f?f.offset:0,o))return Promise.resolve(a);if(f&&o===f.offset+f.length&&o>0){var l=s[o-1];(f.type==="object"&&l==="}"||f.type==="array"&&l==="]")&&(f=f.parent)}var u=this.getCurrentWord(r,o),c;if(f&&(f.type==="string"||f.type==="number"||f.type==="boolean"||f.type==="null"))c=J.create(r.positionAt(f.offset),r.positionAt(f.offset+f.length));else{var h=o-u.length;h>0&&s[h-1]==='"'&&h--,c=J.create(r.positionAt(h),i)}var p=!1,d={},v={add:function(g){var A=g.label,y=d[A];if(y)y.documentation||(y.documentation=g.documentation),y.detail||(y.detail=g.detail);else{if(A=A.replace(/[\n]/g,"\u21B5"),A.length>60){var m=A.substr(0,57).trim()+"...";d[m]||(A=m)}c&&g.insertText!==void 0&&(g.textEdit=ge.replace(c,g.insertText)),p&&(g.commitCharacters=g.kind===ie.Property?Yr:Qr),g.label=A,d[A]=g,a.items.push(g)}},setAsIncomplete:function(){a.isIncomplete=!0},error:function(g){console.error(g)},log:function(g){console.log(g)},getNumberOfProposals:function(){return a.items.length}};return this.schemaService.getSchemaForResource(r.uri,t).then(function(g){var A=[],y=!0,m="",O=void 0;if(f&&f.type==="string"){var E=f.parent;E&&E.type==="property"&&E.keyNode===f&&(y=!E.valueNode,O=E,m=s.substr(f.offset+1,f.length-2),E&&(f=E.parent))}if(f&&f.type==="object"){if(f.offset===o)return a;var P=f.properties;P.forEach(function(C){(!O||O!==C)&&(d[C.keyNode.value]=ct.create("__"))});var w="";y&&(w=n.evaluateSeparatorAfter(r,r.offsetAt(c.end))),g?n.getPropertyCompletions(g,t,f,y,w,v):n.getSchemaLessPropertyCompletions(t,f,m,v);var j=vt(f);n.contributions.forEach(function(C){var F=C.collectPropertyCompletions(r.uri,j,u,y,w==="",v);F&&A.push(F)}),!g&&u.length>0&&s.charAt(o-u.length-1)!=='"'&&(v.add({kind:ie.Property,label:n.getLabelForValue(u),insertText:n.getInsertTextForProperty(u,void 0,!1,w),insertTextFormat:Z.Snippet,documentation:""}),v.setAsIncomplete())}var x={};return g?n.getValueCompletions(g,t,f,o,r,v,x):n.getSchemaLessValueCompletions(t,f,o,r,v),n.contributions.length>0&&n.getContributedValueCompletions(t,f,o,r,v,A),n.promiseConstructor.all(A).then(function(){if(v.getNumberOfProposals()===0){var C=o;f&&(f.type==="string"||f.type==="number"||f.type==="boolean"||f.type==="null")&&(C=f.offset+f.length);var F=n.evaluateSeparatorAfter(r,C);n.addFillerValueCompletions(x,F,v)}return a})})},e.prototype.getPropertyCompletions=function(r,i,t,n,a,s){var o=this,f=i.getMatchingSchemas(r.schema,t.offset);f.forEach(function(l){if(l.node===t&&!l.inverted){var u=l.schema.properties;u&&Object.keys(u).forEach(function(v){var g=u[v];if(typeof g=="object"&&!g.deprecationMessage&&!g.doNotSuggest){var A={kind:ie.Property,label:v,insertText:o.getInsertTextForProperty(v,g,n,a),insertTextFormat:Z.Snippet,filterText:o.getFilterTextForValue(v),documentation:o.fromMarkup(g.markdownDescription)||g.description||""};g.suggestSortText!==void 0&&(A.sortText=g.suggestSortText),A.insertText&&Ve(A.insertText,"$1".concat(a))&&(A.command={title:"Suggest",command:"editor.action.triggerSuggest"}),s.add(A)}});var c=l.schema.propertyNames;if(typeof c=="object"&&!c.deprecationMessage&&!c.doNotSuggest){var h=function(v,g){g===void 0&&(g=void 0);var A={kind:ie.Property,label:v,insertText:o.getInsertTextForProperty(v,void 0,n,a),insertTextFormat:Z.Snippet,filterText:o.getFilterTextForValue(v),documentation:g||o.fromMarkup(c.markdownDescription)||c.description||""};c.suggestSortText!==void 0&&(A.sortText=c.suggestSortText),A.insertText&&Ve(A.insertText,"$1".concat(a))&&(A.command={title:"Suggest",command:"editor.action.triggerSuggest"}),s.add(A)};if(c.enum)for(var p=0;p<c.enum.length;p++){var d=void 0;c.markdownEnumDescriptions&&p<c.markdownEnumDescriptions.length?d=o.fromMarkup(c.markdownEnumDescriptions[p]):c.enumDescriptions&&p<c.enumDescriptions.length&&(d=c.enumDescriptions[p]),h(c.enum[p],d)}c.const&&h(c.const)}}})},e.prototype.getSchemaLessPropertyCompletions=function(r,i,t,n){var a=this,s=function(f){f.properties.forEach(function(l){var u=l.keyNode.value;n.add({kind:ie.Property,label:u,insertText:a.getInsertTextForValue(u,""),insertTextFormat:Z.Snippet,filterText:a.getFilterTextForValue(u),documentation:""})})};if(i.parent)if(i.parent.type==="property"){var o=i.parent.keyNode.value;r.visit(function(f){return f.type==="property"&&f!==i.parent&&f.keyNode.value===o&&f.valueNode&&f.valueNode.type==="object"&&s(f.valueNode),!0})}else i.parent.type==="array"&&i.parent.items.forEach(function(f){f.type==="object"&&f!==i&&s(f)});else i.type==="object"&&n.add({kind:ie.Property,label:"$schema",insertText:this.getInsertTextForProperty("$schema",void 0,!0,""),insertTextFormat:Z.Snippet,documentation:"",filterText:this.getFilterTextForValue("$schema")})},e.prototype.getSchemaLessValueCompletions=function(r,i,t,n,a){var s=this,o=t;if(i&&(i.type==="string"||i.type==="number"||i.type==="boolean"||i.type==="null")&&(o=i.offset+i.length,i=i.parent),!i){a.add({kind:this.getSuggestionKind("object"),label:"Empty object",insertText:this.getInsertTextForValue({},""),insertTextFormat:Z.Snippet,documentation:""}),a.add({kind:this.getSuggestionKind("array"),label:"Empty array",insertText:this.getInsertTextForValue([],""),insertTextFormat:Z.Snippet,documentation:""});return}var f=this.evaluateSeparatorAfter(n,o),l=function(p){p.parent&&!hr(p.parent,t,!0)&&a.add({kind:s.getSuggestionKind(p.type),label:s.getLabelTextForMatchingNode(p,n),insertText:s.getInsertTextForMatchingNode(p,n,f),insertTextFormat:Z.Snippet,documentation:""}),p.type==="boolean"&&s.addBooleanValueCompletion(!p.value,f,a)};if(i.type==="property"&&t>(i.colonOffset||0)){var u=i.valueNode;if(u&&(t>u.offset+u.length||u.type==="object"||u.type==="array"))return;var c=i.keyNode.value;r.visit(function(p){return p.type==="property"&&p.keyNode.value===c&&p.valueNode&&l(p.valueNode),!0}),c==="$schema"&&i.parent&&!i.parent.parent&&this.addDollarSchemaCompletions(f,a)}if(i.type==="array")if(i.parent&&i.parent.type==="property"){var h=i.parent.keyNode.value;r.visit(function(p){return p.type==="property"&&p.keyNode.value===h&&p.valueNode&&p.valueNode.type==="array"&&p.valueNode.items.forEach(l),!0})}else i.items.forEach(l)},e.prototype.getValueCompletions=function(r,i,t,n,a,s,o){var f=n,l=void 0,u=void 0;if(t&&(t.type==="string"||t.type==="number"||t.type==="boolean"||t.type==="null")&&(f=t.offset+t.length,u=t,t=t.parent),!t){this.addSchemaValueCompletions(r.schema,"",s,o);return}if(t.type==="property"&&n>(t.colonOffset||0)){var c=t.valueNode;if(c&&n>c.offset+c.length)return;l=t.keyNode.value,t=t.parent}if(t&&(l!==void 0||t.type==="array")){for(var h=this.evaluateSeparatorAfter(a,f),p=i.getMatchingSchemas(r.schema,t.offset,u),d=0,v=p;d<v.length;d++){var g=v[d];if(g.node===t&&!g.inverted&&g.schema){if(t.type==="array"&&g.schema.items)if(Array.isArray(g.schema.items)){var A=this.findItemAtOffset(t,a,n);A<g.schema.items.length&&this.addSchemaValueCompletions(g.schema.items[A],h,s,o)}else this.addSchemaValueCompletions(g.schema.items,h,s,o);if(l!==void 0){var y=!1;if(g.schema.properties){var m=g.schema.properties[l];m&&(y=!0,this.addSchemaValueCompletions(m,h,s,o))}if(g.schema.patternProperties&&!y)for(var O=0,E=Object.keys(g.schema.patternProperties);O<E.length;O++){var P=E[O],w=ze(P);if(w?.test(l)){y=!0;var m=g.schema.patternProperties[P];this.addSchemaValueCompletions(m,h,s,o)}}if(g.schema.additionalProperties&&!y){var m=g.schema.additionalProperties;this.addSchemaValueCompletions(m,h,s,o)}}}}l==="$schema"&&!t.parent&&this.addDollarSchemaCompletions(h,s),o.boolean&&(this.addBooleanValueCompletion(!0,h,s),this.addBooleanValueCompletion(!1,h,s)),o.null&&this.addNullValueCompletion(h,s)}},e.prototype.getContributedValueCompletions=function(r,i,t,n,a,s){if(!i)this.contributions.forEach(function(u){var c=u.collectDefaultCompletions(n.uri,a);c&&s.push(c)});else if((i.type==="string"||i.type==="number"||i.type==="boolean"||i.type==="null")&&(i=i.parent),i&&i.type==="property"&&t>(i.colonOffset||0)){var o=i.keyNode.value,f=i.valueNode;if((!f||t<=f.offset+f.length)&&i.parent){var l=vt(i.parent);this.contributions.forEach(function(u){var c=u.collectValueCompletions(n.uri,l,o,a);c&&s.push(c)})}}},e.prototype.addSchemaValueCompletions=function(r,i,t,n){var a=this;typeof r=="object"&&(this.addEnumValueCompletions(r,i,t),this.addDefaultValueCompletions(r,i,t),this.collectTypes(r,n),Array.isArray(r.allOf)&&r.allOf.forEach(function(s){return a.addSchemaValueCompletions(s,i,t,n)}),Array.isArray(r.anyOf)&&r.anyOf.forEach(function(s){return a.addSchemaValueCompletions(s,i,t,n)}),Array.isArray(r.oneOf)&&r.oneOf.forEach(function(s){return a.addSchemaValueCompletions(s,i,t,n)}))},e.prototype.addDefaultValueCompletions=function(r,i,t,n){var a=this;n===void 0&&(n=0);var s=!1;if(Ae(r.default)){for(var o=r.type,f=r.default,l=n;l>0;l--)f=[f],o="array";t.add({kind:this.getSuggestionKind(o),label:this.getLabelForValue(f),insertText:this.getInsertTextForValue(f,i),insertTextFormat:Z.Snippet,detail:mt("json.suggest.default","Default value")}),s=!0}Array.isArray(r.examples)&&r.examples.forEach(function(u){for(var c=r.type,h=u,p=n;p>0;p--)h=[h],c="array";t.add({kind:a.getSuggestionKind(c),label:a.getLabelForValue(h),insertText:a.getInsertTextForValue(h,i),insertTextFormat:Z.Snippet}),s=!0}),Array.isArray(r.defaultSnippets)&&r.defaultSnippets.forEach(function(u){var c=r.type,h=u.body,p=u.label,d,v;if(Ae(h)){for(var g=r.type,A=n;A>0;A--)h=[h],g="array";d=a.getInsertTextForSnippetValue(h,i),v=a.getFilterTextForSnippetValue(h),p=p||a.getLabelForSnippetValue(h)}else if(typeof u.bodyText=="string"){for(var y="",m="",O="",A=n;A>0;A--)y=y+O+`[
`,m=m+`
`+O+"]",O+="	",c="array";d=y+O+u.bodyText.split(`
`).join(`
`+O)+m+i,p=p||d,v=d.replace(/[\n]/g,"")}else return;t.add({kind:a.getSuggestionKind(c),label:p,documentation:a.fromMarkup(u.markdownDescription)||u.description,insertText:d,insertTextFormat:Z.Snippet,filterText:v}),s=!0}),!s&&typeof r.items=="object"&&!Array.isArray(r.items)&&n<5&&this.addDefaultValueCompletions(r.items,i,t,n+1)},e.prototype.addEnumValueCompletions=function(r,i,t){if(Ae(r.const)&&t.add({kind:this.getSuggestionKind(r.type),label:this.getLabelForValue(r.const),insertText:this.getInsertTextForValue(r.const,i),insertTextFormat:Z.Snippet,documentation:this.fromMarkup(r.markdownDescription)||r.description}),Array.isArray(r.enum))for(var n=0,a=r.enum.length;n<a;n++){var s=r.enum[n],o=this.fromMarkup(r.markdownDescription)||r.description;r.markdownEnumDescriptions&&n<r.markdownEnumDescriptions.length&&this.doesSupportMarkdown()?o=this.fromMarkup(r.markdownEnumDescriptions[n]):r.enumDescriptions&&n<r.enumDescriptions.length&&(o=r.enumDescriptions[n]),t.add({kind:this.getSuggestionKind(r.type),label:this.getLabelForValue(s),insertText:this.getInsertTextForValue(s,i),insertTextFormat:Z.Snippet,documentation:o})}},e.prototype.collectTypes=function(r,i){if(!(Array.isArray(r.enum)||Ae(r.const))){var t=r.type;Array.isArray(t)?t.forEach(function(n){return i[n]=!0}):t&&(i[t]=!0)}},e.prototype.addFillerValueCompletions=function(r,i,t){r.object&&t.add({kind:this.getSuggestionKind("object"),label:"{}",insertText:this.getInsertTextForGuessedValue({},i),insertTextFormat:Z.Snippet,detail:mt("defaults.object","New object"),documentation:""}),r.array&&t.add({kind:this.getSuggestionKind("array"),label:"[]",insertText:this.getInsertTextForGuessedValue([],i),insertTextFormat:Z.Snippet,detail:mt("defaults.array","New array"),documentation:""})},e.prototype.addBooleanValueCompletion=function(r,i,t){t.add({kind:this.getSuggestionKind("boolean"),label:r?"true":"false",insertText:this.getInsertTextForValue(r,i),insertTextFormat:Z.Snippet,documentation:""})},e.prototype.addNullValueCompletion=function(r,i){i.add({kind:this.getSuggestionKind("null"),label:"null",insertText:"null"+r,insertTextFormat:Z.Snippet,documentation:""})},e.prototype.addDollarSchemaCompletions=function(r,i){var t=this,n=this.schemaService.getRegisteredSchemaIds(function(a){return a==="http"||a==="https"});n.forEach(function(a){return i.add({kind:ie.Module,label:t.getLabelForValue(a),filterText:t.getFilterTextForValue(a),insertText:t.getInsertTextForValue(a,r),insertTextFormat:Z.Snippet,documentation:""})})},e.prototype.getLabelForValue=function(r){return JSON.stringify(r)},e.prototype.getFilterTextForValue=function(r){return JSON.stringify(r)},e.prototype.getFilterTextForSnippetValue=function(r){return JSON.stringify(r).replace(/\$\{\d+:([^}]+)\}|\$\d+/g,"$1")},e.prototype.getLabelForSnippetValue=function(r){var i=JSON.stringify(r);return i.replace(/\$\{\d+:([^}]+)\}|\$\d+/g,"$1")},e.prototype.getInsertTextForPlainText=function(r){return r.replace(/[\\\$\}]/g,"\\$&")},e.prototype.getInsertTextForValue=function(r,i){var t=JSON.stringify(r,null,"	");return t==="{}"?"{$1}"+i:t==="[]"?"[$1]"+i:this.getInsertTextForPlainText(t+i)},e.prototype.getInsertTextForSnippetValue=function(r,i){var t=function(n){return typeof n=="string"&&n[0]==="^"?n.substr(1):JSON.stringify(n)};return dt(r,"",t)+i},e.prototype.getInsertTextForGuessedValue=function(r,i){switch(typeof r){case"object":return r===null?"${1:null}"+i:this.getInsertTextForValue(r,i);case"string":var t=JSON.stringify(r);return t=t.substr(1,t.length-2),t=this.getInsertTextForPlainText(t),'"${1:'+t+'}"'+i;case"number":case"boolean":return"${1:"+JSON.stringify(r)+"}"+i}return this.getInsertTextForValue(r,i)},e.prototype.getSuggestionKind=function(r){if(Array.isArray(r)){var i=r;r=i.length>0?i[0]:void 0}if(!r)return ie.Value;switch(r){case"string":return ie.Value;case"object":return ie.Module;case"property":return ie.Property;default:return ie.Value}},e.prototype.getLabelTextForMatchingNode=function(r,i){switch(r.type){case"array":return"[]";case"object":return"{}";default:var t=i.getText().substr(r.offset,r.length);return t}},e.prototype.getInsertTextForMatchingNode=function(r,i,t){switch(r.type){case"array":return this.getInsertTextForValue([],t);case"object":return this.getInsertTextForValue({},t);default:var n=i.getText().substr(r.offset,r.length)+t;return this.getInsertTextForPlainText(n)}},e.prototype.getInsertTextForProperty=function(r,i,t,n){var a=this.getInsertTextForValue(r,"");if(!t)return a;var s=a+": ",o,f=0;if(i){if(Array.isArray(i.defaultSnippets)){if(i.defaultSnippets.length===1){var l=i.defaultSnippets[0].body;Ae(l)&&(o=this.getInsertTextForSnippetValue(l,""))}f+=i.defaultSnippets.length}if(i.enum&&(!o&&i.enum.length===1&&(o=this.getInsertTextForGuessedValue(i.enum[0],"")),f+=i.enum.length),Ae(i.default)&&(o||(o=this.getInsertTextForGuessedValue(i.default,"")),f++),Array.isArray(i.examples)&&i.examples.length&&(o||(o=this.getInsertTextForGuessedValue(i.examples[0],"")),f+=i.examples.length),f===0){var u=Array.isArray(i.type)?i.type[0]:i.type;switch(u||(i.properties?u="object":i.items&&(u="array")),u){case"boolean":o="$1";break;case"string":o='"$1"';break;case"object":o="{$1}";break;case"array":o="[$1]";break;case"number":case"integer":o="${1:0}";break;case"null":o="${1:null}";break;default:return a}}}return(!o||f>1)&&(o="$1"),s+o+n},e.prototype.getCurrentWord=function(r,i){for(var t=i-1,n=r.getText();t>=0&&` 	
\r\v":{[,]}`.indexOf(n.charAt(t))===-1;)t--;return n.substring(t+1,i)},e.prototype.evaluateSeparatorAfter=function(r,i){var t=Ie(r.getText(),!0);t.setPosition(i);var n=t.scan();switch(n){case 5:case 2:case 4:case 17:return"";default:return","}},e.prototype.findItemAtOffset=function(r,i,t){for(var n=Ie(i.getText(),!0),a=r.items,s=a.length-1;s>=0;s--){var o=a[s];if(t>o.offset+o.length){n.setPosition(o.offset+o.length);var f=n.scan();return f===5&&t>=n.getTokenOffset()+n.getTokenLength()?s+1:s}else if(t>=o.offset)return s}return 0},e.prototype.isInComment=function(r,i,t){var n=Ie(r.getText(),!1);n.setPosition(i);for(var a=n.scan();a!==17&&n.getTokenOffset()+n.getTokenLength()<t;)a=n.scan();return(a===12||a===13)&&n.getTokenOffset()<=t},e.prototype.fromMarkup=function(r){if(r&&this.doesSupportMarkdown())return{kind:we.Markdown,value:r}},e.prototype.doesSupportMarkdown=function(){if(!Ae(this.supportsMarkdown)){var r=this.clientCapabilities.textDocument&&this.clientCapabilities.textDocument.completion;this.supportsMarkdown=r&&r.completionItem&&Array.isArray(r.completionItem.documentationFormat)&&r.completionItem.documentationFormat.indexOf(we.Markdown)!==-1}return this.supportsMarkdown},e.prototype.doesSupportsCommitCharacters=function(){if(!Ae(this.supportsCommitCharacters)){var r=this.clientCapabilities.textDocument&&this.clientCapabilities.textDocument.completion;this.supportsCommitCharacters=r&&r.completionItem&&!!r.completionItem.commitCharactersSupport}return this.supportsCommitCharacters},e}(),en=function(){function e(r,i,t){i===void 0&&(i=[]),this.schemaService=r,this.contributions=i,this.promise=t||Promise}return e.prototype.doHover=function(r,i,t){var n=r.offsetAt(i),a=t.getNodeFromOffset(n);if(!a||(a.type==="object"||a.type==="array")&&n>a.offset+1&&n<a.offset+a.length-1)return this.promise.resolve(null);var s=a;if(a.type==="string"){var o=a.parent;if(o&&o.type==="property"&&o.keyNode===a&&(a=o.valueNode,!a))return this.promise.resolve(null)}for(var f=J.create(r.positionAt(s.offset),r.positionAt(s.offset+s.length)),l=function(d){var v={contents:d,range:f};return v},u=vt(a),c=this.contributions.length-1;c>=0;c--){var h=this.contributions[c],p=h.getInfoContribution(r.uri,u);if(p)return p.then(function(d){return l(d)})}return this.schemaService.getSchemaForResource(r.uri,t).then(function(d){if(d&&a){var v=t.getMatchingSchemas(d.schema,a.offset),g=void 0,A=void 0,y=void 0,m=void 0;v.every(function(E){if(E.node===a&&!E.inverted&&E.schema&&(g=g||E.schema.title,A=A||E.schema.markdownDescription||yt(E.schema.description),E.schema.enum)){var P=E.schema.enum.indexOf(je(a));E.schema.markdownEnumDescriptions?y=E.schema.markdownEnumDescriptions[P]:E.schema.enumDescriptions&&(y=yt(E.schema.enumDescriptions[P])),y&&(m=E.schema.enum[P],typeof m!="string"&&(m=JSON.stringify(m)))}return!0});var O="";return g&&(O=yt(g)),A&&(O.length>0&&(O+=`

`),O+=A),y&&(O.length>0&&(O+=`

`),O+="`".concat(tn(m),"`: ").concat(y)),l([O])}return null})},e}();function yt(e){if(e){var r=e.replace(/([^\n\r])(\r?\n)([^\n\r])/gm,`$1

$3`);return r.replace(/[\\`*_{}[\]()#+\-.!]/g,"\\$&")}}function tn(e){return e.indexOf("`")!==-1?"`` "+e+" ``":e}var rn=Re(),nn=function(){function e(r,i){this.jsonSchemaService=r,this.promise=i,this.validationEnabled=!0}return e.prototype.configure=function(r){r&&(this.validationEnabled=r.validate!==!1,this.commentSeverity=r.allowComments?void 0:fe.Error)},e.prototype.doValidation=function(r,i,t,n){var a=this;if(!this.validationEnabled)return this.promise.resolve([]);var s=[],o={},f=function(h){var p=h.range.start.line+" "+h.range.start.character+" "+h.message;o[p]||(o[p]=!0,s.push(h))},l=function(h){var p=t?.trailingCommas?Ke(t.trailingCommas):fe.Error,d=t?.comments?Ke(t.comments):a.commentSeverity,v=t?.schemaValidation?Ke(t.schemaValidation):fe.Warning,g=t?.schemaRequest?Ke(t.schemaRequest):fe.Warning;if(h){if(h.errors.length&&i.root&&g){var A=i.root,y=A.type==="object"?A.properties[0]:void 0;if(y&&y.keyNode.value==="$schema"){var m=y.valueNode||y,O=J.create(r.positionAt(m.offset),r.positionAt(m.offset+m.length));f(Se.create(O,h.errors[0],g,U.SchemaResolveError))}else{var O=J.create(r.positionAt(A.offset),r.positionAt(A.offset+1));f(Se.create(O,h.errors[0],g,U.SchemaResolveError))}}else if(v){var E=i.validate(r,h.schema,v);E&&E.forEach(f)}pr(h.schema)&&(d=void 0),vr(h.schema)&&(p=void 0)}for(var P=0,w=i.syntaxErrors;P<w.length;P++){var j=w[P];if(j.code===U.TrailingComma){if(typeof p!="number")continue;j.severity=p}f(j)}if(typeof d=="number"){var x=rn("InvalidCommentToken","Comments are not permitted in JSON.");i.comments.forEach(function(C){f(Se.create(C,x,d,U.CommentNotPermitted))})}return s};if(n){var u=n.id||"schemaservice://untitled/"+an++,c=this.jsonSchemaService.registerExternalSchema(u,[],n);return c.getResolvedSchema().then(function(h){return l(h)})}return this.jsonSchemaService.getSchemaForResource(r.uri,i).then(function(h){return l(h)})},e.prototype.getLanguageStatus=function(r,i){return{schemas:this.jsonSchemaService.getSchemaURIsForResource(r.uri,i)}},e}(),an=0;function pr(e){if(e&&typeof e=="object"){if(pe(e.allowComments))return e.allowComments;if(e.allOf)for(var r=0,i=e.allOf;r<i.length;r++){var t=i[r],n=pr(t);if(pe(n))return n}}}function vr(e){if(e&&typeof e=="object"){if(pe(e.allowTrailingCommas))return e.allowTrailingCommas;var r=e;if(pe(r.allowsTrailingCommas))return r.allowsTrailingCommas;if(e.allOf)for(var i=0,t=e.allOf;i<t.length;i++){var n=t[i],a=vr(n);if(pe(a))return a}}}function Ke(e){switch(e){case"error":return fe.Error;case"warning":return fe.Warning;case"ignore":return}}var dr=48,on=57,sn=65,et=97,fn=102;function X(e){return e<dr?0:e<=on?e-dr:(e<et&&(e+=et-sn),e>=et&&e<=fn?e-et+10:0)}function un(e){if(e[0]==="#")switch(e.length){case 4:return{red:X(e.charCodeAt(1))*17/255,green:X(e.charCodeAt(2))*17/255,blue:X(e.charCodeAt(3))*17/255,alpha:1};case 5:return{red:X(e.charCodeAt(1))*17/255,green:X(e.charCodeAt(2))*17/255,blue:X(e.charCodeAt(3))*17/255,alpha:X(e.charCodeAt(4))*17/255};case 7:return{red:(X(e.charCodeAt(1))*16+X(e.charCodeAt(2)))/255,green:(X(e.charCodeAt(3))*16+X(e.charCodeAt(4)))/255,blue:(X(e.charCodeAt(5))*16+X(e.charCodeAt(6)))/255,alpha:1};case 9:return{red:(X(e.charCodeAt(1))*16+X(e.charCodeAt(2)))/255,green:(X(e.charCodeAt(3))*16+X(e.charCodeAt(4)))/255,blue:(X(e.charCodeAt(5))*16+X(e.charCodeAt(6)))/255,alpha:(X(e.charCodeAt(7))*16+X(e.charCodeAt(8)))/255}}}var cn=function(){function e(r){this.schemaService=r}return e.prototype.findDocumentSymbols=function(r,i,t){var n=this;t===void 0&&(t={resultLimit:Number.MAX_VALUE});var a=i.root;if(!a)return[];var s=t.resultLimit||Number.MAX_VALUE,o=r.uri;if((o==="vscode://defaultsettings/keybindings.json"||Ve(o.toLowerCase(),"/user/keybindings.json"))&&a.type==="array"){for(var f=[],l=0,u=a.items;l<u.length;l++){var c=u[l];if(c.type==="object")for(var h=0,p=c.properties;h<p.length;h++){var d=p[h];if(d.keyNode.value==="key"&&d.valueNode){var v=Le.create(r.uri,ke(r,c));if(f.push({name:je(d.valueNode),kind:ve.Function,location:v}),s--,s<=0)return t&&t.onResultLimitExceeded&&t.onResultLimitExceeded(o),f}}}return f}for(var g=[{node:a,containerName:""}],A=0,y=!1,m=[],O=function(P,w){P.type==="array"?P.items.forEach(function(j){j&&g.push({node:j,containerName:w})}):P.type==="object"&&P.properties.forEach(function(j){var x=j.valueNode;if(x)if(s>0){s--;var C=Le.create(r.uri,ke(r,j)),F=w?w+"."+j.keyNode.value:j.keyNode.value;m.push({name:n.getKeyLabel(j),kind:n.getSymbolKind(x.type),location:C,containerName:w}),g.push({node:x,containerName:F})}else y=!0})};A<g.length;){var E=g[A++];O(E.node,E.containerName)}return y&&t&&t.onResultLimitExceeded&&t.onResultLimitExceeded(o),m},e.prototype.findDocumentSymbols2=function(r,i,t){var n=this;t===void 0&&(t={resultLimit:Number.MAX_VALUE});var a=i.root;if(!a)return[];var s=t.resultLimit||Number.MAX_VALUE,o=r.uri;if((o==="vscode://defaultsettings/keybindings.json"||Ve(o.toLowerCase(),"/user/keybindings.json"))&&a.type==="array"){for(var f=[],l=0,u=a.items;l<u.length;l++){var c=u[l];if(c.type==="object")for(var h=0,p=c.properties;h<p.length;h++){var d=p[h];if(d.keyNode.value==="key"&&d.valueNode){var v=ke(r,c),g=ke(r,d.keyNode);if(f.push({name:je(d.valueNode),kind:ve.Function,range:v,selectionRange:g}),s--,s<=0)return t&&t.onResultLimitExceeded&&t.onResultLimitExceeded(o),f}}}return f}for(var A=[],y=[{node:a,result:A}],m=0,O=!1,E=function(w,j){w.type==="array"?w.items.forEach(function(x,C){if(x)if(s>0){s--;var F=ke(r,x),N=F,V=String(C),D={name:V,kind:n.getSymbolKind(x.type),range:F,selectionRange:N,children:[]};j.push(D),y.push({result:D.children,node:x})}else O=!0}):w.type==="object"&&w.properties.forEach(function(x){var C=x.valueNode;if(C)if(s>0){s--;var F=ke(r,x),N=ke(r,x.keyNode),V=[],D={name:n.getKeyLabel(x),kind:n.getSymbolKind(C.type),range:F,selectionRange:N,children:V,detail:n.getDetail(C)};j.push(D),y.push({result:V,node:C})}else O=!0})};m<y.length;){var P=y[m++];E(P.node,P.result)}return O&&t&&t.onResultLimitExceeded&&t.onResultLimitExceeded(o),A},e.prototype.getSymbolKind=function(r){switch(r){case"object":return ve.Module;case"string":return ve.String;case"number":return ve.Number;case"array":return ve.Array;case"boolean":return ve.Boolean;default:return ve.Variable}},e.prototype.getKeyLabel=function(r){var i=r.keyNode.value;return i&&(i=i.replace(/[\n]/g,"\u21B5")),i&&i.trim()?i:'"'.concat(i,'"')},e.prototype.getDetail=function(r){if(r){if(r.type==="boolean"||r.type==="number"||r.type==="null"||r.type==="string")return String(r.value);if(r.type==="array")return r.children.length?void 0:"[]";if(r.type==="object")return r.children.length?void 0:"{}"}},e.prototype.findDocumentColors=function(r,i,t){return this.schemaService.getSchemaForResource(r.uri,i).then(function(n){var a=[];if(n)for(var s=t&&typeof t.resultLimit=="number"?t.resultLimit:Number.MAX_VALUE,o=i.getMatchingSchemas(n.schema),f={},l=0,u=o;l<u.length;l++){var c=u[l];if(!c.inverted&&c.schema&&(c.schema.format==="color"||c.schema.format==="color-hex")&&c.node&&c.node.type==="string"){var h=String(c.node.offset);if(!f[h]){var p=un(je(c.node));if(p){var d=ke(r,c.node);a.push({color:p,range:d})}if(f[h]=!0,s--,s<=0)return t&&t.onResultLimitExceeded&&t.onResultLimitExceeded(r.uri),a}}}return a})},e.prototype.getColorPresentations=function(r,i,t,n){var a=[],s=Math.round(t.red*255),o=Math.round(t.green*255),f=Math.round(t.blue*255);function l(c){var h=c.toString(16);return h.length!==2?"0"+h:h}var u;return t.alpha===1?u="#".concat(l(s)).concat(l(o)).concat(l(f)):u="#".concat(l(s)).concat(l(o)).concat(l(f)).concat(l(Math.round(t.alpha*255))),a.push({label:u,textEdit:ge.replace(n,JSON.stringify(u))}),a},e}();function ke(e,r){return J.create(e.positionAt(r.offset),e.positionAt(r.offset+r.length))}var $=Re(),bt={schemaAssociations:[],schemas:{"http://json-schema.org/schema#":{$ref:"http://json-schema.org/draft-07/schema#"},"http://json-schema.org/draft-04/schema#":{$schema:"http://json-schema.org/draft-04/schema#",definitions:{schemaArray:{type:"array",minItems:1,items:{$ref:"#"}},positiveInteger:{type:"integer",minimum:0},positiveIntegerDefault0:{allOf:[{$ref:"#/definitions/positiveInteger"},{default:0}]},simpleTypes:{type:"string",enum:["array","boolean","integer","null","number","object","string"]},stringArray:{type:"array",items:{type:"string"},minItems:1,uniqueItems:!0}},type:"object",properties:{id:{type:"string",format:"uri"},$schema:{type:"string",format:"uri"},title:{type:"string"},description:{type:"string"},default:{},multipleOf:{type:"number",minimum:0,exclusiveMinimum:!0},maximum:{type:"number"},exclusiveMaximum:{type:"boolean",default:!1},minimum:{type:"number"},exclusiveMinimum:{type:"boolean",default:!1},maxLength:{allOf:[{$ref:"#/definitions/positiveInteger"}]},minLength:{allOf:[{$ref:"#/definitions/positiveIntegerDefault0"}]},pattern:{type:"string",format:"regex"},additionalItems:{anyOf:[{type:"boolean"},{$ref:"#"}],default:{}},items:{anyOf:[{$ref:"#"},{$ref:"#/definitions/schemaArray"}],default:{}},maxItems:{allOf:[{$ref:"#/definitions/positiveInteger"}]},minItems:{allOf:[{$ref:"#/definitions/positiveIntegerDefault0"}]},uniqueItems:{type:"boolean",default:!1},maxProperties:{allOf:[{$ref:"#/definitions/positiveInteger"}]},minProperties:{allOf:[{$ref:"#/definitions/positiveIntegerDefault0"}]},required:{allOf:[{$ref:"#/definitions/stringArray"}]},additionalProperties:{anyOf:[{type:"boolean"},{$ref:"#"}],default:{}},definitions:{type:"object",additionalProperties:{$ref:"#"},default:{}},properties:{type:"object",additionalProperties:{$ref:"#"},default:{}},patternProperties:{type:"object",additionalProperties:{$ref:"#"},default:{}},dependencies:{type:"object",additionalProperties:{anyOf:[{$ref:"#"},{$ref:"#/definitions/stringArray"}]}},enum:{type:"array",minItems:1,uniqueItems:!0},type:{anyOf:[{$ref:"#/definitions/simpleTypes"},{type:"array",items:{$ref:"#/definitions/simpleTypes"},minItems:1,uniqueItems:!0}]},format:{anyOf:[{type:"string",enum:["date-time","uri","email","hostname","ipv4","ipv6","regex"]},{type:"string"}]},allOf:{allOf:[{$ref:"#/definitions/schemaArray"}]},anyOf:{allOf:[{$ref:"#/definitions/schemaArray"}]},oneOf:{allOf:[{$ref:"#/definitions/schemaArray"}]},not:{allOf:[{$ref:"#"}]}},dependencies:{exclusiveMaximum:["maximum"],exclusiveMinimum:["minimum"]},default:{}},"http://json-schema.org/draft-07/schema#":{definitions:{schemaArray:{type:"array",minItems:1,items:{$ref:"#"}},nonNegativeInteger:{type:"integer",minimum:0},nonNegativeIntegerDefault0:{allOf:[{$ref:"#/definitions/nonNegativeInteger"},{default:0}]},simpleTypes:{enum:["array","boolean","integer","null","number","object","string"]},stringArray:{type:"array",items:{type:"string"},uniqueItems:!0,default:[]}},type:["object","boolean"],properties:{$id:{type:"string",format:"uri-reference"},$schema:{type:"string",format:"uri"},$ref:{type:"string",format:"uri-reference"},$comment:{type:"string"},title:{type:"string"},description:{type:"string"},default:!0,readOnly:{type:"boolean",default:!1},examples:{type:"array",items:!0},multipleOf:{type:"number",exclusiveMinimum:0},maximum:{type:"number"},exclusiveMaximum:{type:"number"},minimum:{type:"number"},exclusiveMinimum:{type:"number"},maxLength:{$ref:"#/definitions/nonNegativeInteger"},minLength:{$ref:"#/definitions/nonNegativeIntegerDefault0"},pattern:{type:"string",format:"regex"},additionalItems:{$ref:"#"},items:{anyOf:[{$ref:"#"},{$ref:"#/definitions/schemaArray"}],default:!0},maxItems:{$ref:"#/definitions/nonNegativeInteger"},minItems:{$ref:"#/definitions/nonNegativeIntegerDefault0"},uniqueItems:{type:"boolean",default:!1},contains:{$ref:"#"},maxProperties:{$ref:"#/definitions/nonNegativeInteger"},minProperties:{$ref:"#/definitions/nonNegativeIntegerDefault0"},required:{$ref:"#/definitions/stringArray"},additionalProperties:{$ref:"#"},definitions:{type:"object",additionalProperties:{$ref:"#"},default:{}},properties:{type:"object",additionalProperties:{$ref:"#"},default:{}},patternProperties:{type:"object",additionalProperties:{$ref:"#"},propertyNames:{format:"regex"},default:{}},dependencies:{type:"object",additionalProperties:{anyOf:[{$ref:"#"},{$ref:"#/definitions/stringArray"}]}},propertyNames:{$ref:"#"},const:!0,enum:{type:"array",items:!0,minItems:1,uniqueItems:!0},type:{anyOf:[{$ref:"#/definitions/simpleTypes"},{type:"array",items:{$ref:"#/definitions/simpleTypes"},minItems:1,uniqueItems:!0}]},format:{type:"string"},contentMediaType:{type:"string"},contentEncoding:{type:"string"},if:{$ref:"#"},then:{$ref:"#"},else:{$ref:"#"},allOf:{$ref:"#/definitions/schemaArray"},anyOf:{$ref:"#/definitions/schemaArray"},oneOf:{$ref:"#/definitions/schemaArray"},not:{$ref:"#"}},default:!0}}},ln={id:$("schema.json.id","A unique identifier for the schema."),$schema:$("schema.json.$schema","The schema to verify this document against."),title:$("schema.json.title","A descriptive title of the element."),description:$("schema.json.description","A long description of the element. Used in hover menus and suggestions."),default:$("schema.json.default","A default value. Used by suggestions."),multipleOf:$("schema.json.multipleOf","A number that should cleanly divide the current value (i.e. have no remainder)."),maximum:$("schema.json.maximum","The maximum numerical value, inclusive by default."),exclusiveMaximum:$("schema.json.exclusiveMaximum","Makes the maximum property exclusive."),minimum:$("schema.json.minimum","The minimum numerical value, inclusive by default."),exclusiveMinimum:$("schema.json.exclusiveMininum","Makes the minimum property exclusive."),maxLength:$("schema.json.maxLength","The maximum length of a string."),minLength:$("schema.json.minLength","The minimum length of a string."),pattern:$("schema.json.pattern","A regular expression to match the string against. It is not implicitly anchored."),additionalItems:$("schema.json.additionalItems","For arrays, only when items is set as an array. If it is a schema, then this schema validates items after the ones specified by the items array. If it is false, then additional items will cause validation to fail."),items:$("schema.json.items","For arrays. Can either be a schema to validate every element against or an array of schemas to validate each item against in order (the first schema will validate the first element, the second schema will validate the second element, and so on."),maxItems:$("schema.json.maxItems","The maximum number of items that can be inside an array. Inclusive."),minItems:$("schema.json.minItems","The minimum number of items that can be inside an array. Inclusive."),uniqueItems:$("schema.json.uniqueItems","If all of the items in the array must be unique. Defaults to false."),maxProperties:$("schema.json.maxProperties","The maximum number of properties an object can have. Inclusive."),minProperties:$("schema.json.minProperties","The minimum number of properties an object can have. Inclusive."),required:$("schema.json.required","An array of strings that lists the names of all properties required on this object."),additionalProperties:$("schema.json.additionalProperties","Either a schema or a boolean. If a schema, then used to validate all properties not matched by 'properties' or 'patternProperties'. If false, then any properties not matched by either will cause this schema to fail."),definitions:$("schema.json.definitions","Not used for validation. Place subschemas here that you wish to reference inline with $ref."),properties:$("schema.json.properties","A map of property names to schemas for each property."),patternProperties:$("schema.json.patternProperties","A map of regular expressions on property names to schemas for matching properties."),dependencies:$("schema.json.dependencies","A map of property names to either an array of property names or a schema. An array of property names means the property named in the key depends on the properties in the array being present in the object in order to be valid. If the value is a schema, then the schema is only applied to the object if the property in the key exists on the object."),enum:$("schema.json.enum","The set of literal values that are valid."),type:$("schema.json.type","Either a string of one of the basic schema types (number, integer, null, array, object, boolean, string) or an array of strings specifying a subset of those types."),format:$("schema.json.format","Describes the format expected for the value."),allOf:$("schema.json.allOf","An array of schemas, all of which must match."),anyOf:$("schema.json.anyOf","An array of schemas, where at least one must match."),oneOf:$("schema.json.oneOf","An array of schemas, exactly one of which must match."),not:$("schema.json.not","A schema which must not match."),$id:$("schema.json.$id","A unique identifier for the schema."),$ref:$("schema.json.$ref","Reference a definition hosted on any location."),$comment:$("schema.json.$comment","Comments from schema authors to readers or maintainers of the schema."),readOnly:$("schema.json.readOnly","Indicates that the value of the instance is managed exclusively by the owning authority."),examples:$("schema.json.examples","Sample JSON values associated with a particular schema, for the purpose of illustrating usage."),contains:$("schema.json.contains",'An array instance is valid against "contains" if at least one of its elements is valid against the given schema.'),propertyNames:$("schema.json.propertyNames","If the instance is an object, this keyword validates if every property name in the instance validates against the provided schema."),const:$("schema.json.const","An instance validates successfully against this keyword if its value is equal to the value of the keyword."),contentMediaType:$("schema.json.contentMediaType","Describes the media type of a string property."),contentEncoding:$("schema.json.contentEncoding","Describes the content encoding of a string property."),if:$("schema.json.if",'The validation outcome of the "if" subschema controls which of the "then" or "else" keywords are evaluated.'),then:$("schema.json.then",'The "if" subschema is used for validation when the "if" subschema succeeds.'),else:$("schema.json.else",'The "else" subschema is used for validation when the "if" subschema fails.')};for(mr in bt.schemas){tt=bt.schemas[mr];for(Pe in tt.properties)rt=tt.properties[Pe],typeof rt=="boolean"&&(rt=tt.properties[Pe]={}),At=ln[Pe],At?rt.description=At:console.log("".concat(Pe,": localize('schema.json.").concat(Pe,`', "")`))}var tt,rt,At,Pe,mr,yr;yr=(()=>{"use strict";var e={470:t=>{function n(o){if(typeof o!="string")throw new TypeError("Path must be a string. Received "+JSON.stringify(o))}function a(o,f){for(var l,u="",c=0,h=-1,p=0,d=0;d<=o.length;++d){if(d<o.length)l=o.charCodeAt(d);else{if(l===47)break;l=47}if(l===47){if(!(h===d-1||p===1))if(h!==d-1&&p===2){if(u.length<2||c!==2||u.charCodeAt(u.length-1)!==46||u.charCodeAt(u.length-2)!==46){if(u.length>2){var v=u.lastIndexOf("/");if(v!==u.length-1){v===-1?(u="",c=0):c=(u=u.slice(0,v)).length-1-u.lastIndexOf("/"),h=d,p=0;continue}}else if(u.length===2||u.length===1){u="",c=0,h=d,p=0;continue}}f&&(u.length>0?u+="/..":u="..",c=2)}else u.length>0?u+="/"+o.slice(h+1,d):u=o.slice(h+1,d),c=d-h-1;h=d,p=0}else l===46&&p!==-1?++p:p=-1}return u}var s={resolve:function(){for(var o,f="",l=!1,u=arguments.length-1;u>=-1&&!l;u--){var c;u>=0?c=arguments[u]:(o===void 0&&(o=process.cwd()),c=o),n(c),c.length!==0&&(f=c+"/"+f,l=c.charCodeAt(0)===47)}return f=a(f,!l),l?f.length>0?"/"+f:"/":f.length>0?f:"."},normalize:function(o){if(n(o),o.length===0)return".";var f=o.charCodeAt(0)===47,l=o.charCodeAt(o.length-1)===47;return(o=a(o,!f)).length!==0||f||(o="."),o.length>0&&l&&(o+="/"),f?"/"+o:o},isAbsolute:function(o){return n(o),o.length>0&&o.charCodeAt(0)===47},join:function(){if(arguments.length===0)return".";for(var o,f=0;f<arguments.length;++f){var l=arguments[f];n(l),l.length>0&&(o===void 0?o=l:o+="/"+l)}return o===void 0?".":s.normalize(o)},relative:function(o,f){if(n(o),n(f),o===f||(o=s.resolve(o))===(f=s.resolve(f)))return"";for(var l=1;l<o.length&&o.charCodeAt(l)===47;++l);for(var u=o.length,c=u-l,h=1;h<f.length&&f.charCodeAt(h)===47;++h);for(var p=f.length-h,d=c<p?c:p,v=-1,g=0;g<=d;++g){if(g===d){if(p>d){if(f.charCodeAt(h+g)===47)return f.slice(h+g+1);if(g===0)return f.slice(h+g)}else c>d&&(o.charCodeAt(l+g)===47?v=g:g===0&&(v=0));break}var A=o.charCodeAt(l+g);if(A!==f.charCodeAt(h+g))break;A===47&&(v=g)}var y="";for(g=l+v+1;g<=u;++g)g!==u&&o.charCodeAt(g)!==47||(y.length===0?y+="..":y+="/..");return y.length>0?y+f.slice(h+v):(h+=v,f.charCodeAt(h)===47&&++h,f.slice(h))},_makeLong:function(o){return o},dirname:function(o){if(n(o),o.length===0)return".";for(var f=o.charCodeAt(0),l=f===47,u=-1,c=!0,h=o.length-1;h>=1;--h)if((f=o.charCodeAt(h))===47){if(!c){u=h;break}}else c=!1;return u===-1?l?"/":".":l&&u===1?"//":o.slice(0,u)},basename:function(o,f){if(f!==void 0&&typeof f!="string")throw new TypeError('"ext" argument must be a string');n(o);var l,u=0,c=-1,h=!0;if(f!==void 0&&f.length>0&&f.length<=o.length){if(f.length===o.length&&f===o)return"";var p=f.length-1,d=-1;for(l=o.length-1;l>=0;--l){var v=o.charCodeAt(l);if(v===47){if(!h){u=l+1;break}}else d===-1&&(h=!1,d=l+1),p>=0&&(v===f.charCodeAt(p)?--p==-1&&(c=l):(p=-1,c=d))}return u===c?c=d:c===-1&&(c=o.length),o.slice(u,c)}for(l=o.length-1;l>=0;--l)if(o.charCodeAt(l)===47){if(!h){u=l+1;break}}else c===-1&&(h=!1,c=l+1);return c===-1?"":o.slice(u,c)},extname:function(o){n(o);for(var f=-1,l=0,u=-1,c=!0,h=0,p=o.length-1;p>=0;--p){var d=o.charCodeAt(p);if(d!==47)u===-1&&(c=!1,u=p+1),d===46?f===-1?f=p:h!==1&&(h=1):f!==-1&&(h=-1);else if(!c){l=p+1;break}}return f===-1||u===-1||h===0||h===1&&f===u-1&&f===l+1?"":o.slice(f,u)},format:function(o){if(o===null||typeof o!="object")throw new TypeError('The "pathObject" argument must be of type Object. Received type '+typeof o);return function(f,l){var u=l.dir||l.root,c=l.base||(l.name||"")+(l.ext||"");return u?u===l.root?u+c:u+"/"+c:c}(0,o)},parse:function(o){n(o);var f={root:"",dir:"",base:"",ext:"",name:""};if(o.length===0)return f;var l,u=o.charCodeAt(0),c=u===47;c?(f.root="/",l=1):l=0;for(var h=-1,p=0,d=-1,v=!0,g=o.length-1,A=0;g>=l;--g)if((u=o.charCodeAt(g))!==47)d===-1&&(v=!1,d=g+1),u===46?h===-1?h=g:A!==1&&(A=1):h!==-1&&(A=-1);else if(!v){p=g+1;break}return h===-1||d===-1||A===0||A===1&&h===d-1&&h===p+1?d!==-1&&(f.base=f.name=p===0&&c?o.slice(1,d):o.slice(p,d)):(p===0&&c?(f.name=o.slice(1,h),f.base=o.slice(1,d)):(f.name=o.slice(p,h),f.base=o.slice(p,d)),f.ext=o.slice(h,d)),p>0?f.dir=o.slice(0,p-1):c&&(f.dir="/"),f},sep:"/",delimiter:":",win32:null,posix:null};s.posix=s,t.exports=s},447:(t,n,a)=>{var s;if(a.r(n),a.d(n,{URI:()=>y,Utils:()=>V}),typeof process=="object")s=process.platform==="win32";else if(typeof navigator=="object"){var o=navigator.userAgent;s=o.indexOf("Windows")>=0}var f,l,u=(f=function(k,S){return(f=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(T,I){T.__proto__=I}||function(T,I){for(var L in I)Object.prototype.hasOwnProperty.call(I,L)&&(T[L]=I[L])})(k,S)},function(k,S){if(typeof S!="function"&&S!==null)throw new TypeError("Class extends value "+String(S)+" is not a constructor or null");function T(){this.constructor=k}f(k,S),k.prototype=S===null?Object.create(S):(T.prototype=S.prototype,new T)}),c=/^\w[\w\d+.-]*$/,h=/^\//,p=/^\/\//;function d(k,S){if(!k.scheme&&S)throw new Error('[UriError]: Scheme is missing: {scheme: "", authority: "'.concat(k.authority,'", path: "').concat(k.path,'", query: "').concat(k.query,'", fragment: "').concat(k.fragment,'"}'));if(k.scheme&&!c.test(k.scheme))throw new Error("[UriError]: Scheme contains illegal characters.");if(k.path){if(k.authority){if(!h.test(k.path))throw new Error('[UriError]: If a URI contains an authority component, then the path component must either be empty or begin with a slash ("/") character')}else if(p.test(k.path))throw new Error('[UriError]: If a URI does not contain an authority component, then the path cannot begin with two slash characters ("//")')}}var v="",g="/",A=/^(([^:/?#]+?):)?(\/\/([^/?#]*))?([^?#]*)(\?([^#]*))?(#(.*))?/,y=function(){function k(S,T,I,L,_,R){R===void 0&&(R=!1),typeof S=="object"?(this.scheme=S.scheme||v,this.authority=S.authority||v,this.path=S.path||v,this.query=S.query||v,this.fragment=S.fragment||v):(this.scheme=function(me,re){return me||re?me:"file"}(S,R),this.authority=T||v,this.path=function(me,re){switch(me){case"https":case"http":case"file":re?re[0]!==g&&(re=g+re):re=g}return re}(this.scheme,I||v),this.query=L||v,this.fragment=_||v,d(this,R))}return k.isUri=function(S){return S instanceof k||!!S&&typeof S.authority=="string"&&typeof S.fragment=="string"&&typeof S.path=="string"&&typeof S.query=="string"&&typeof S.scheme=="string"&&typeof S.fsPath=="string"&&typeof S.with=="function"&&typeof S.toString=="function"},Object.defineProperty(k.prototype,"fsPath",{get:function(){return j(this,!1)},enumerable:!1,configurable:!0}),k.prototype.with=function(S){if(!S)return this;var T=S.scheme,I=S.authority,L=S.path,_=S.query,R=S.fragment;return T===void 0?T=this.scheme:T===null&&(T=v),I===void 0?I=this.authority:I===null&&(I=v),L===void 0?L=this.path:L===null&&(L=v),_===void 0?_=this.query:_===null&&(_=v),R===void 0?R=this.fragment:R===null&&(R=v),T===this.scheme&&I===this.authority&&L===this.path&&_===this.query&&R===this.fragment?this:new O(T,I,L,_,R)},k.parse=function(S,T){T===void 0&&(T=!1);var I=A.exec(S);return I?new O(I[2]||v,N(I[4]||v),N(I[5]||v),N(I[7]||v),N(I[9]||v),T):new O(v,v,v,v,v)},k.file=function(S){var T=v;if(s&&(S=S.replace(/\\/g,g)),S[0]===g&&S[1]===g){var I=S.indexOf(g,2);I===-1?(T=S.substring(2),S=g):(T=S.substring(2,I),S=S.substring(I)||g)}return new O("file",T,S,v,v)},k.from=function(S){var T=new O(S.scheme,S.authority,S.path,S.query,S.fragment);return d(T,!0),T},k.prototype.toString=function(S){return S===void 0&&(S=!1),x(this,S)},k.prototype.toJSON=function(){return this},k.revive=function(S){if(S){if(S instanceof k)return S;var T=new O(S);return T._formatted=S.external,T._fsPath=S._sep===m?S.fsPath:null,T}return S},k}(),m=s?1:void 0,O=function(k){function S(){var T=k!==null&&k.apply(this,arguments)||this;return T._formatted=null,T._fsPath=null,T}return u(S,k),Object.defineProperty(S.prototype,"fsPath",{get:function(){return this._fsPath||(this._fsPath=j(this,!1)),this._fsPath},enumerable:!1,configurable:!0}),S.prototype.toString=function(T){return T===void 0&&(T=!1),T?x(this,!0):(this._formatted||(this._formatted=x(this,!1)),this._formatted)},S.prototype.toJSON=function(){var T={$mid:1};return this._fsPath&&(T.fsPath=this._fsPath,T._sep=m),this._formatted&&(T.external=this._formatted),this.path&&(T.path=this.path),this.scheme&&(T.scheme=this.scheme),this.authority&&(T.authority=this.authority),this.query&&(T.query=this.query),this.fragment&&(T.fragment=this.fragment),T},S}(y),E=((l={})[58]="%3A",l[47]="%2F",l[63]="%3F",l[35]="%23",l[91]="%5B",l[93]="%5D",l[64]="%40",l[33]="%21",l[36]="%24",l[38]="%26",l[39]="%27",l[40]="%28",l[41]="%29",l[42]="%2A",l[43]="%2B",l[44]="%2C",l[59]="%3B",l[61]="%3D",l[32]="%20",l);function P(k,S){for(var T=void 0,I=-1,L=0;L<k.length;L++){var _=k.charCodeAt(L);if(_>=97&&_<=122||_>=65&&_<=90||_>=48&&_<=57||_===45||_===46||_===95||_===126||S&&_===47)I!==-1&&(T+=encodeURIComponent(k.substring(I,L)),I=-1),T!==void 0&&(T+=k.charAt(L));else{T===void 0&&(T=k.substr(0,L));var R=E[_];R!==void 0?(I!==-1&&(T+=encodeURIComponent(k.substring(I,L)),I=-1),T+=R):I===-1&&(I=L)}}return I!==-1&&(T+=encodeURIComponent(k.substring(I))),T!==void 0?T:k}function w(k){for(var S=void 0,T=0;T<k.length;T++){var I=k.charCodeAt(T);I===35||I===63?(S===void 0&&(S=k.substr(0,T)),S+=E[I]):S!==void 0&&(S+=k[T])}return S!==void 0?S:k}function j(k,S){var T;return T=k.authority&&k.path.length>1&&k.scheme==="file"?"//".concat(k.authority).concat(k.path):k.path.charCodeAt(0)===47&&(k.path.charCodeAt(1)>=65&&k.path.charCodeAt(1)<=90||k.path.charCodeAt(1)>=97&&k.path.charCodeAt(1)<=122)&&k.path.charCodeAt(2)===58?S?k.path.substr(1):k.path[1].toLowerCase()+k.path.substr(2):k.path,s&&(T=T.replace(/\//g,"\\")),T}function x(k,S){var T=S?w:P,I="",L=k.scheme,_=k.authority,R=k.path,me=k.query,re=k.fragment;if(L&&(I+=L,I+=":"),(_||L==="file")&&(I+=g,I+=g),_){var le=_.indexOf("@");if(le!==-1){var Me=_.substr(0,le);_=_.substr(le+1),(le=Me.indexOf(":"))===-1?I+=T(Me,!1):(I+=T(Me.substr(0,le),!1),I+=":",I+=T(Me.substr(le+1),!1)),I+="@"}(le=(_=_.toLowerCase()).indexOf(":"))===-1?I+=T(_,!1):(I+=T(_.substr(0,le),!1),I+=_.substr(le))}if(R){if(R.length>=3&&R.charCodeAt(0)===47&&R.charCodeAt(2)===58)(ye=R.charCodeAt(1))>=65&&ye<=90&&(R="/".concat(String.fromCharCode(ye+32),":").concat(R.substr(3)));else if(R.length>=2&&R.charCodeAt(1)===58){var ye;(ye=R.charCodeAt(0))>=65&&ye<=90&&(R="".concat(String.fromCharCode(ye+32),":").concat(R.substr(2)))}I+=T(R,!0)}return me&&(I+="?",I+=T(me,!1)),re&&(I+="#",I+=S?re:P(re,!1)),I}function C(k){try{return decodeURIComponent(k)}catch{return k.length>3?k.substr(0,3)+C(k.substr(3)):k}}var F=/(%[0-9A-Za-z][0-9A-Za-z])+/g;function N(k){return k.match(F)?k.replace(F,function(S){return C(S)}):k}var V,D=a(470),te=function(k,S,T){if(T||arguments.length===2)for(var I,L=0,_=S.length;L<_;L++)!I&&L in S||(I||(I=Array.prototype.slice.call(S,0,L)),I[L]=S[L]);return k.concat(I||Array.prototype.slice.call(S))},z=D.posix||D;(function(k){k.joinPath=function(S){for(var T=[],I=1;I<arguments.length;I++)T[I-1]=arguments[I];return S.with({path:z.join.apply(z,te([S.path],T,!1))})},k.resolvePath=function(S){for(var T=[],I=1;I<arguments.length;I++)T[I-1]=arguments[I];var L=S.path||"/";return S.with({path:z.resolve.apply(z,te([L],T,!1))})},k.dirname=function(S){var T=z.dirname(S.path);return T.length===1&&T.charCodeAt(0)===46?S:S.with({path:T})},k.basename=function(S){return z.basename(S.path)},k.extname=function(S){return z.extname(S.path)}})(V||(V={}))}},r={};function i(t){if(r[t])return r[t].exports;var n=r[t]={exports:{}};return e[t](n,n.exports,i),n.exports}return i.d=(t,n)=>{for(var a in n)i.o(n,a)&&!i.o(t,a)&&Object.defineProperty(t,a,{enumerable:!0,get:n[a]})},i.o=(t,n)=>Object.prototype.hasOwnProperty.call(t,n),i.r=t=>{typeof Symbol<"u"&&Symbol.toStringTag&&Object.defineProperty(t,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(t,"__esModule",{value:!0})},i(447)})();var{URI:Ne,Utils:Ln}=yr;function hn(e,r){if(typeof e!="string")throw new TypeError("Expected a string");for(var i=String(e),t="",n=r?!!r.extended:!1,a=r?!!r.globstar:!1,s=!1,o=r&&typeof r.flags=="string"?r.flags:"",f,l=0,u=i.length;l<u;l++)switch(f=i[l],f){case"/":case"$":case"^":case"+":case".":case"(":case")":case"=":case"!":case"|":t+="\\"+f;break;case"?":if(n){t+=".";break}case"[":case"]":if(n){t+=f;break}case"{":if(n){s=!0,t+="(";break}case"}":if(n){s=!1,t+=")";break}case",":if(s){t+="|";break}t+="\\"+f;break;case"*":for(var c=i[l-1],h=1;i[l+1]==="*";)h++,l++;var p=i[l+1];if(!a)t+=".*";else{var d=h>1&&(c==="/"||c===void 0||c==="{"||c===",")&&(p==="/"||p===void 0||p===","||p==="}");d?(p==="/"?l++:c==="/"&&t.endsWith("\\/")&&(t=t.substr(0,t.length-2)),t+="((?:[^/]*(?:/|$))*)"):t+="([^/]*)"}break;default:t+=f}return(!o||!~o.indexOf("g"))&&(t="^"+t+"$"),new RegExp(t,o)}var de=Re(),gn="!",pn="/",vn=function(){function e(r,i){this.globWrappers=[];try{for(var t=0,n=r;t<n.length;t++){var a=n[t],s=a[0]!==gn;s||(a=a.substring(1)),a.length>0&&(a[0]===pn&&(a=a.substring(1)),this.globWrappers.push({regexp:hn("**/"+a,{extended:!0,globstar:!0}),include:s}))}this.uris=i}catch{this.globWrappers.length=0,this.uris=[]}}return e.prototype.matchesPattern=function(r){for(var i=!1,t=0,n=this.globWrappers;t<n.length;t++){var a=n[t],s=a.regexp,o=a.include;s.test(r)&&(i=o)}return i},e.prototype.getURIs=function(){return this.uris},e}(),dn=function(){function e(r,i,t){this.service=r,this.uri=i,this.dependencies=new Set,this.anchors=void 0,t&&(this.unresolvedSchema=this.service.promise.resolve(new qe(t)))}return e.prototype.getUnresolvedSchema=function(){return this.unresolvedSchema||(this.unresolvedSchema=this.service.loadSchema(this.uri)),this.unresolvedSchema},e.prototype.getResolvedSchema=function(){var r=this;return this.resolvedSchema||(this.resolvedSchema=this.getUnresolvedSchema().then(function(i){return r.service.resolveSchemaContent(i,r)})),this.resolvedSchema},e.prototype.clearSchema=function(){var r=!!this.unresolvedSchema;return this.resolvedSchema=void 0,this.unresolvedSchema=void 0,this.dependencies.clear(),this.anchors=void 0,r},e}(),qe=function(){function e(r,i){i===void 0&&(i=[]),this.schema=r,this.errors=i}return e}(),br=function(){function e(r,i){i===void 0&&(i=[]),this.schema=r,this.errors=i}return e.prototype.getSection=function(r){var i=this.getSectionRecursive(r,this.schema);if(i)return ae(i)},e.prototype.getSectionRecursive=function(r,i){if(!i||typeof i=="boolean"||r.length===0)return i;var t=r.shift();if(i.properties&&typeof i.properties[t])return this.getSectionRecursive(r,i.properties[t]);if(i.patternProperties)for(var n=0,a=Object.keys(i.patternProperties);n<a.length;n++){var s=a[n],o=ze(s);if(o?.test(t))return this.getSectionRecursive(r,i.patternProperties[s])}else{if(typeof i.additionalProperties=="object")return this.getSectionRecursive(r,i.additionalProperties);if(t.match("[0-9]+")){if(Array.isArray(i.items)){var f=parseInt(t,10);if(!isNaN(f)&&i.items[f])return this.getSectionRecursive(r,i.items[f])}else if(i.items)return this.getSectionRecursive(r,i.items)}}},e}(),mn=function(){function e(r,i,t){this.contextService=i,this.requestService=r,this.promiseConstructor=t||Promise,this.callOnDispose=[],this.contributionSchemas={},this.contributionAssociations=[],this.schemasById={},this.filePatternAssociations=[],this.registeredSchemasIds={}}return e.prototype.getRegisteredSchemaIds=function(r){return Object.keys(this.registeredSchemasIds).filter(function(i){var t=Ne.parse(i).scheme;return t!=="schemaservice"&&(!r||r(t))})},Object.defineProperty(e.prototype,"promise",{get:function(){return this.promiseConstructor},enumerable:!1,configurable:!0}),e.prototype.dispose=function(){for(;this.callOnDispose.length>0;)this.callOnDispose.pop()()},e.prototype.onResourceChange=function(r){var i=this;this.cachedSchemaForResource=void 0;var t=!1;r=Te(r);for(var n=[r],a=Object.keys(this.schemasById).map(function(l){return i.schemasById[l]});n.length;)for(var s=n.pop(),o=0;o<a.length;o++){var f=a[o];f&&(f.uri===s||f.dependencies.has(s))&&(f.uri!==s&&n.push(f.uri),f.clearSchema()&&(t=!0),a[o]=void 0)}return t},e.prototype.setSchemaContributions=function(r){if(r.schemas){var i=r.schemas;for(var t in i){var n=Te(t);this.contributionSchemas[n]=this.addSchemaHandle(n,i[t])}}if(Array.isArray(r.schemaAssociations))for(var a=r.schemaAssociations,s=0,o=a;s<o.length;s++){var f=o[s],l=f.uris.map(Te),u=this.addFilePatternAssociation(f.pattern,l);this.contributionAssociations.push(u)}},e.prototype.addSchemaHandle=function(r,i){var t=new dn(this,r,i);return this.schemasById[r]=t,t},e.prototype.getOrAddSchemaHandle=function(r,i){return this.schemasById[r]||this.addSchemaHandle(r,i)},e.prototype.addFilePatternAssociation=function(r,i){var t=new vn(r,i);return this.filePatternAssociations.push(t),t},e.prototype.registerExternalSchema=function(r,i,t){var n=Te(r);return this.registeredSchemasIds[n]=!0,this.cachedSchemaForResource=void 0,i&&this.addFilePatternAssociation(i,[n]),t?this.addSchemaHandle(n,t):this.getOrAddSchemaHandle(n)},e.prototype.clearExternalSchemas=function(){this.schemasById={},this.filePatternAssociations=[],this.registeredSchemasIds={},this.cachedSchemaForResource=void 0;for(var r in this.contributionSchemas)this.schemasById[r]=this.contributionSchemas[r],this.registeredSchemasIds[r]=!0;for(var i=0,t=this.contributionAssociations;i<t.length;i++){var n=t[i];this.filePatternAssociations.push(n)}},e.prototype.getResolvedSchema=function(r){var i=Te(r),t=this.schemasById[i];return t?t.getResolvedSchema():this.promise.resolve(void 0)},e.prototype.loadSchema=function(r){if(!this.requestService){var i=de("json.schema.norequestservice","Unable to load schema from '{0}'. No schema request service available",nt(r));return this.promise.resolve(new qe({},[i]))}return this.requestService(r).then(function(t){if(!t){var n=de("json.schema.nocontent","Unable to load schema from '{0}': No content.",nt(r));return new qe({},[n])}var a={},s=[];a=Pr(t,s);var o=s.length?[de("json.schema.invalidFormat","Unable to parse content from '{0}': Parse error at offset {1}.",nt(r),s[0].offset)]:[];return new qe(a,o)},function(t){var n=t.toString(),a=t.toString().split("Error: ");return a.length>1&&(n=a[1]),Ve(n,".")&&(n=n.substr(0,n.length-1)),new qe({},[de("json.schema.nocontent","Unable to load schema from '{0}': {1}.",nt(r),n)])})},e.prototype.resolveSchemaContent=function(r,i){var t=this,n=r.errors.slice(0),a=r.schema;if(a.$schema){var s=Te(a.$schema);if(s==="http://json-schema.org/draft-03/schema")return this.promise.resolve(new br({},[de("json.schema.draft03.notsupported","Draft-03 schemas are not supported.")]));s==="https://json-schema.org/draft/2019-09/schema"?n.push(de("json.schema.draft201909.notsupported","Draft 2019-09 schemas are not yet fully supported.")):s==="https://json-schema.org/draft/2020-12/schema"&&n.push(de("json.schema.draft202012.notsupported","Draft 2020-12 schemas are not yet fully supported."))}var o=this.contextService,f=function(v,g){g=decodeURIComponent(g);var A=v;return g[0]==="/"&&(g=g.substring(1)),g.split("/").some(function(y){return y=y.replace(/~1/g,"/").replace(/~0/g,"~"),A=A[y],!A}),A},l=function(v,g,A){return g.anchors||(g.anchors=d(v)),g.anchors.get(A)},u=function(v,g){for(var A in g)g.hasOwnProperty(A)&&!v.hasOwnProperty(A)&&A!=="id"&&A!=="$id"&&(v[A]=g[A])},c=function(v,g,A,y){var m;y===void 0||y.length===0?m=g:y.charAt(0)==="/"?m=f(g,y):m=l(g,A,y),m?u(v,m):n.push(de("json.schema.invalidid","$ref '{0}' in '{1}' can not be resolved.",y,A.uri))},h=function(v,g,A,y){o&&!/^[A-Za-z][A-Za-z0-9+\-.+]*:\/\/.*/.test(g)&&(g=o.resolveRelativePath(g,y.uri)),g=Te(g);var m=t.getOrAddSchemaHandle(g);return m.getUnresolvedSchema().then(function(O){if(y.dependencies.add(g),O.errors.length){var E=A?g+"#"+A:g;n.push(de("json.schema.problemloadingref","Problems loading reference '{0}': {1}",E,O.errors[0]))}return c(v,O.schema,m,A),p(v,O.schema,m)})},p=function(v,g,A){var y=[];return t.traverseNodes(v,function(m){for(var O=new Set;m.$ref;){var E=m.$ref,P=E.split("#",2);if(delete m.$ref,P[0].length>0){y.push(h(m,P[0],P[1],A));return}else if(!O.has(E)){var w=P[1];c(m,g,A,w),O.add(E)}}}),t.promise.all(y)},d=function(v){var g=new Map;return t.traverseNodes(v,function(A){var y=A.$id||A.id;if(typeof y=="string"&&y.charAt(0)==="#"){var m=y.substring(1);g.has(m)?n.push(de("json.schema.duplicateid","Duplicate id declaration: '{0}'",y)):g.set(m,A)}}),g};return p(a,a,i).then(function(v){return new br(a,n)})},e.prototype.traverseNodes=function(r,i){if(!r||typeof r!="object")return Promise.resolve(null);for(var t=new Set,n=function(){for(var l=[],u=0;u<arguments.length;u++)l[u]=arguments[u];for(var c=0,h=l;c<h.length;c++){var p=h[c];typeof p=="object"&&o.push(p)}},a=function(){for(var l=[],u=0;u<arguments.length;u++)l[u]=arguments[u];for(var c=0,h=l;c<h.length;c++){var p=h[c];if(typeof p=="object")for(var d in p){var v=d,g=p[v];typeof g=="object"&&o.push(g)}}},s=function(){for(var l=[],u=0;u<arguments.length;u++)l[u]=arguments[u];for(var c=0,h=l;c<h.length;c++){var p=h[c];if(Array.isArray(p))for(var d=0,v=p;d<v.length;d++){var g=v[d];typeof g=="object"&&o.push(g)}}},o=[r],f=o.pop();f;)t.has(f)||(t.add(f),i(f),n(f.items,f.additionalItems,f.additionalProperties,f.not,f.contains,f.propertyNames,f.if,f.then,f.else),a(f.definitions,f.properties,f.patternProperties,f.dependencies),s(f.anyOf,f.allOf,f.oneOf,f.items)),f=o.pop()},e.prototype.getSchemaFromProperty=function(r,i){var t,n;if(((t=i.root)===null||t===void 0?void 0:t.type)==="object")for(var a=0,s=i.root.properties;a<s.length;a++){var o=s[a];if(o.keyNode.value==="$schema"&&((n=o.valueNode)===null||n===void 0?void 0:n.type)==="string"){var f=o.valueNode.value;return this.contextService&&!/^\w[\w\d+.-]*:/.test(f)&&(f=this.contextService.resolveRelativePath(f,r)),f}}},e.prototype.getAssociatedSchemas=function(r){for(var i=Object.create(null),t=[],n=bn(r),a=0,s=this.filePatternAssociations;a<s.length;a++){var o=s[a];if(o.matchesPattern(n))for(var f=0,l=o.getURIs();f<l.length;f++){var u=l[f];i[u]||(t.push(u),i[u]=!0)}}return t},e.prototype.getSchemaURIsForResource=function(r,i){var t=i&&this.getSchemaFromProperty(r,i);return t?[t]:this.getAssociatedSchemas(r)},e.prototype.getSchemaForResource=function(r,i){if(i){var t=this.getSchemaFromProperty(r,i);if(t){var n=Te(t);return this.getOrAddSchemaHandle(n).getResolvedSchema()}}if(this.cachedSchemaForResource&&this.cachedSchemaForResource.resource===r)return this.cachedSchemaForResource.resolvedSchema;var a=this.getAssociatedSchemas(r),s=a.length>0?this.createCombinedSchema(r,a).getResolvedSchema():this.promise.resolve(void 0);return this.cachedSchemaForResource={resource:r,resolvedSchema:s},s},e.prototype.createCombinedSchema=function(r,i){if(i.length===1)return this.getOrAddSchemaHandle(i[0]);var t="schemaservice://combinedSchema/"+encodeURIComponent(r),n={allOf:i.map(function(a){return{$ref:a}})};return this.addSchemaHandle(t,n)},e.prototype.getMatchingSchemas=function(r,i,t){if(t){var n=t.id||"schemaservice://untitled/matchingSchemas/"+yn++,a=this.addSchemaHandle(n,t);return a.getResolvedSchema().then(function(s){return i.getMatchingSchemas(s.schema).filter(function(o){return!o.inverted})})}return this.getSchemaForResource(r.uri,i).then(function(s){return s?i.getMatchingSchemas(s.schema).filter(function(o){return!o.inverted}):[]})},e}(),yn=0;function Te(e){try{return Ne.parse(e).toString(!0)}catch{return e}}function bn(e){try{return Ne.parse(e).with({fragment:null,query:null}).toString(!0)}catch{return e}}function nt(e){try{var r=Ne.parse(e);if(r.scheme==="file")return r.fsPath}catch{}return e}function An(e,r){var i=[],t=[],n=[],a=-1,s=Ie(e.getText(),!1),o=s.scan();function f(C){i.push(C),t.push(n.length)}for(;o!==17;){switch(o){case 1:case 3:{var l=e.positionAt(s.getTokenOffset()).line,u={startLine:l,endLine:l,kind:o===1?"object":"array"};n.push(u);break}case 2:case 4:{var c=o===2?"object":"array";if(n.length>0&&n[n.length-1].kind===c){var u=n.pop(),h=e.positionAt(s.getTokenOffset()).line;u&&h>u.startLine+1&&a!==u.startLine&&(u.endLine=h-1,f(u),a=u.startLine)}break}case 13:{var l=e.positionAt(s.getTokenOffset()).line,p=e.positionAt(s.getTokenOffset()+s.getTokenLength()).line;s.getTokenError()===1&&l+1<e.lineCount?s.setPosition(e.offsetAt(he.create(l+1,0))):l<p&&(f({startLine:l,endLine:p,kind:$e.Comment}),a=l);break}case 12:{var d=e.getText().substr(s.getTokenOffset(),s.getTokenLength()),v=d.match(/^\/\/\s*#(region\b)|(endregion\b)/);if(v){var h=e.positionAt(s.getTokenOffset()).line;if(v[1]){var u={startLine:h,endLine:h,kind:$e.Region};n.push(u)}else{for(var g=n.length-1;g>=0&&n[g].kind!==$e.Region;)g--;if(g>=0){var u=n[g];n.length=g,h>u.startLine&&a!==u.startLine&&(u.endLine=h,f(u),a=u.startLine)}}}break}}o=s.scan()}var A=r&&r.rangeLimit;if(typeof A!="number"||i.length<=A)return i;r&&r.onRangeLimitExceeded&&r.onRangeLimitExceeded(e.uri);for(var y=[],m=0,O=t;m<O.length;m++){var E=O[m];E<30&&(y[E]=(y[E]||0)+1)}for(var P=0,w=0,g=0;g<y.length;g++){var j=y[g];if(j){if(j+P>A){w=g;break}P+=j}}for(var x=[],g=0;g<i.length;g++){var E=t[g];typeof E=="number"&&(E<w||E===w&&P++<A)&&x.push(i[g])}return x}function Sn(e,r,i){function t(o){for(var f=e.offsetAt(o),l=i.getNodeFromOffset(f,!0),u=[];l;){switch(l.type){case"string":case"object":case"array":var c=l.offset+1,h=l.offset+l.length-1;c<h&&f>=c&&f<=h&&u.push(n(c,h)),u.push(n(l.offset,l.offset+l.length));break;case"number":case"boolean":case"null":case"property":u.push(n(l.offset,l.offset+l.length));break}if(l.type==="property"||l.parent&&l.parent.type==="array"){var p=s(l.offset+l.length,5);p!==-1&&u.push(n(l.offset,p))}l=l.parent}for(var d=void 0,v=u.length-1;v>=0;v--)d=Qe.create(u[v],d);return d||(d=Qe.create(J.create(o,o))),d}function n(o,f){return J.create(e.positionAt(o),e.positionAt(f))}var a=Ie(e.getText(),!0);function s(o,f){a.setPosition(o);var l=a.scan();return l===f?a.getTokenOffset()+a.getTokenLength():-1}return r.map(t)}function wn(e,r){var i=[];return r.visit(function(t){var n;if(t.type==="property"&&t.keyNode.value==="$ref"&&((n=t.valueNode)===null||n===void 0?void 0:n.type)==="string"){var a=t.valueNode.value,s=kn(r,a);if(s){var o=e.positionAt(s.offset);i.push({target:"".concat(e.uri,"#").concat(o.line+1,",").concat(o.character+1),range:xn(e,t.valueNode)})}}return!0}),Promise.resolve(i)}function xn(e,r){return J.create(e.positionAt(r.offset+1),e.positionAt(r.offset+r.length-1))}function kn(e,r){var i=Tn(r);return i?St(i,e.root):null}function St(e,r){if(!r)return null;if(e.length===0)return r;var i=e.shift();if(r&&r.type==="object"){var t=r.properties.find(function(s){return s.keyNode.value===i});return t?St(e,t.valueNode):null}else if(r&&r.type==="array"&&i.match(/^(0|[1-9][0-9]*)$/)){var n=Number.parseInt(i),a=r.items[n];return a?St(e,a):null}return null}function Tn(e){return e==="#"?[]:e[0]!=="#"||e[1]!=="/"?null:e.substring(2).split(/\//).map(On)}function On(e){return e.replace(/~1/g,"/").replace(/~0/g,"~")}function Cn(e){var r=e.promiseConstructor||Promise,i=new mn(e.schemaRequestService,e.workspaceContext,r);i.setSchemaContributions(bt);var t=new Kr(i,e.contributions,r,e.clientCapabilities),n=new en(i,e.contributions,r),a=new cn(i),s=new nn(i,r);return{configure:function(o){i.clearExternalSchemas(),o.schemas&&o.schemas.forEach(function(f){i.registerExternalSchema(f.uri,f.fileMatch,f.schema)}),s.configure(o)},resetSchema:function(o){return i.onResourceChange(o)},doValidation:s.doValidation.bind(s),getLanguageStatus:s.getLanguageStatus.bind(s),parseJSONDocument:function(o){return Zr(o,{collectComments:!0})},newJSONDocument:function(o,f){return Xr(o,f)},getMatchingSchemas:i.getMatchingSchemas.bind(i),doResolve:t.doResolve.bind(t),doComplete:t.doComplete.bind(t),findDocumentSymbols:a.findDocumentSymbols.bind(a),findDocumentSymbols2:a.findDocumentSymbols2.bind(a),findDocumentColors:a.findDocumentColors.bind(a),getColorPresentations:a.getColorPresentations.bind(a),doHover:n.doHover.bind(n),getFoldingRanges:An,getSelectionRanges:Sn,findDefinition:function(){return Promise.resolve([])},findLinks:wn,format:function(o,f,l){var u=void 0;if(f){var c=o.offsetAt(f.start),h=o.offsetAt(f.end)-c;u={offset:c,length:h}}var p={tabSize:l?l.tabSize:4,insertSpaces:l?.insertSpaces===!0,insertFinalNewline:l?.insertFinalNewline===!0,eol:`
`};return Vr(o.getText(),u,p).map(function(d){return ge.replace(J.create(o.positionAt(d.offset),o.positionAt(d.offset+d.length)),d.content)})}}}var Ar;typeof fetch<"u"&&(Ar=function(e){return fetch(e).then(r=>r.text())});var jn=class{_ctx;_languageService;_languageSettings;_languageId;constructor(e,r){this._ctx=e,this._languageSettings=r.languageSettings,this._languageId=r.languageId,this._languageService=Cn({workspaceContext:{resolveRelativePath:(i,t)=>{const n=t.substr(0,t.lastIndexOf("/")+1);return Pn(n,i)}},schemaRequestService:r.enableSchemaRequest?Ar:void 0}),this._languageService.configure(this._languageSettings)}async doValidation(e){let r=this._getTextDocument(e);if(r){let i=this._languageService.parseJSONDocument(r);return this._languageService.doValidation(r,i,this._languageSettings)}return Promise.resolve([])}async doComplete(e,r){let i=this._getTextDocument(e);if(!i)return null;let t=this._languageService.parseJSONDocument(i);return this._languageService.doComplete(i,r,t)}async doResolve(e){return this._languageService.doResolve(e)}async doHover(e,r){let i=this._getTextDocument(e);if(!i)return null;let t=this._languageService.parseJSONDocument(i);return this._languageService.doHover(i,r,t)}async format(e,r,i){let t=this._getTextDocument(e);if(!t)return[];let n=this._languageService.format(t,r,i);return Promise.resolve(n)}async resetSchema(e){return Promise.resolve(this._languageService.resetSchema(e))}async findDocumentSymbols(e){let r=this._getTextDocument(e);if(!r)return[];let i=this._languageService.parseJSONDocument(r),t=this._languageService.findDocumentSymbols(r,i);return Promise.resolve(t)}async findDocumentColors(e){let r=this._getTextDocument(e);if(!r)return[];let i=this._languageService.parseJSONDocument(r),t=this._languageService.findDocumentColors(r,i);return Promise.resolve(t)}async getColorPresentations(e,r,i){let t=this._getTextDocument(e);if(!t)return[];let n=this._languageService.parseJSONDocument(t),a=this._languageService.getColorPresentations(t,n,r,i);return Promise.resolve(a)}async getFoldingRanges(e,r){let i=this._getTextDocument(e);if(!i)return[];let t=this._languageService.getFoldingRanges(i,r);return Promise.resolve(t)}async getSelectionRanges(e,r){let i=this._getTextDocument(e);if(!i)return[];let t=this._languageService.parseJSONDocument(i),n=this._languageService.getSelectionRanges(i,r,t);return Promise.resolve(n)}_getTextDocument(e){let r=this._ctx.getMirrorModels();for(let i of r)if(i.uri.toString()===e)return lt.create(e,this._languageId,i.version,i.getValue());return null}},In=47,wt=46;function En(e){return e.charCodeAt(0)===In}function Pn(e,r){if(En(r)){const i=Ne.parse(e),t=r.split("/");return i.with({path:Sr(t)}).toString()}return Nn(e,r)}function Sr(e){const r=[];for(const t of e)t.length===0||t.length===1&&t.charCodeAt(0)===wt||(t.length===2&&t.charCodeAt(0)===wt&&t.charCodeAt(1)===wt?r.pop():r.push(t));e.length>1&&e[e.length-1].length===0&&r.push("");let i=r.join("/");return e[0].length===0&&(i="/"+i),i}function Nn(e,...r){const i=Ne.parse(e),t=i.path.split("/");for(let n of r)t.push(...n.split("/"));return i.with({path:Sr(t)}).toString()}self.onmessage=()=>{be.n((e,r)=>new jn(e,r))}}},Ct={};function q(W){var Q=Ct[W];if(Q!==void 0)return Q.exports;var B=Ct[W]={exports:{}};return Ot[W](B,B.exports,q),B.exports}q.m=Ot,q.x=()=>{var W=q.O(void 0,[630,3169],()=>q(81162));return W=q.O(W),W},(()=>{var W=[];q.O=(Q,B,be,G)=>{if(B){G=G||0;for(var H=W.length;H>0&&W[H-1][2]>G;H--)W[H]=W[H-1];W[H]=[B,be,G];return}for(var K=1/0,H=0;H<W.length;H++){for(var[B,be,G]=W[H],ne=!0,ue=0;ue<B.length;ue++)(G&!1||K>=G)&&Object.keys(q.O).every(it=>q.O[it](B[ue]))?B.splice(ue--,1):(ne=!1,G<K&&(K=G));if(ne){W.splice(H--,1);var ce=be();ce!==void 0&&(Q=ce)}}return Q}})(),q.d=(W,Q)=>{for(var B in Q)q.o(Q,B)&&!q.o(W,B)&&Object.defineProperty(W,B,{enumerable:!0,get:Q[B]})},q.f={},q.e=W=>Promise.all(Object.keys(q.f).reduce((Q,B)=>(q.f[B](W,Q),Q),[])),q.u=W=>""+W+"."+{630:"d205c8330b40621c3a04",3169:"b94ac7494fcee0766a2a"}[W]+".js",q.miniCssF=W=>{},q.g=function(){if(typeof globalThis=="object")return globalThis;try{return this||new Function("return this")()}catch{if(typeof window=="object")return window}}(),q.o=(W,Q)=>Object.prototype.hasOwnProperty.call(W,Q),q.p=__webpack_worker_public_path__||"public/build/",(()=>{var W={1162:1,1821:1},Q=G=>{var[H,K,ne]=G;for(var ue in K)q.o(K,ue)&&(q.m[ue]=K[ue]);for(ne&&ne(q);H.length;)W[H.pop()]=1;be(G)};q.f.i=(G,H)=>{W[G]||importScripts(q.p+q.u(G))};var B=self.webpackChunkgrafana=self.webpackChunkgrafana||[],be=B.push.bind(B);B.push=Q})(),(()=>{var W=q.x;q.x=()=>Promise.all([q.e(630),q.e(3169)]).then(W)})();var Fn=q.x()})();

//# sourceMappingURL=1162.60ebec2c71e65f273267.js.map